@@ -2,18 +2,20 @@
 /*
  *  Copyright © 2012 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -21,14 +23,16 @@
 
 #include "ephy-embed-shell.h"
 #include "ephy-embed-prefs.h"
+#include "ephy-embed-utils.h"
 #include "ephy-file-helpers.h"
+#include "ephy-flatpak-utils.h"
 #include "ephy-history-service.h"
 #include "ephy-prefs.h"
 #include "ephy-settings.h"
 #include "ephy-smaps.h"
 #include "ephy-snapshot-service.h"
+#include "ephy-vcs-version.h"
 #include "ephy-web-app-utils.h"
-#include "ephy-embed-private.h"
 
 #include <gio/gio.h>
 #include <gtk/gtk.h>
@@ -43,7 +47,7 @@ struct _EphyAboutHandler {
 G_DEFINE_TYPE (EphyAboutHandler, ephy_about_handler, G_TYPE_OBJECT)
 
 
-#define EPHY_ABOUT_OVERVIEW_MAX_ITEMS 10
+#define EPHY_ABOUT_OVERVIEW_MAX_ITEMS 9
 
 #define EPHY_PAGE_TEMPLATE_ABOUT_CSS        "ephy-resource:///org/gnome/epiphany/page-templates/about.css"
 
@@ -267,11 +271,11 @@ ephy_about_handler_handle_about (EphyAboutHandler       *handler,
   char *version;
   GtkIconInfo *icon_info;
 
-  version = g_strdup_printf (_("Version %s"), VERSION);
+  version = g_strdup_printf (_("Version %s"), VCSVERSION);
 
   icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
-                                          "web-browser",
-                                          256,
+                                          "org.gnome.Epiphany",
+                                          512,
                                           GTK_ICON_LOOKUP_GENERIC_FALLBACK);
 
   data = g_strdup_printf ("<html><head><title>%s</title>"
@@ -282,7 +286,7 @@ ephy_about_handler_handle_about (EphyAboutHandler       *handler,
                           "<img src=\"file://%s\"/>"
                           "<h1 id=\"about-title\">%s</h1>"
                           "<h2 id=\"about-subtitle\">%s</h2>"
-                          "<p id=\"about-tagline\">“%s”</p>"
+                          "<p id=\"about-tagline\">%s</p>"
                           "<table class=\"properties\">"
                           "<tr><td class=\"prop-label\">%s</td><td class=\"prop-value\">%d.%d.%d</td></tr>"
                           "</table>"
@@ -444,9 +448,8 @@ history_service_query_urls_cb (EphyHistoryService     *history,
                           "      }\n"
                           "    }\n"
                           "    function removeFromOverview(elem, event) {\n"
-                          "      var listItemNode = elem;\n"
                           "      event.preventDefault();\n"
-                          "      listItemNode.className +=\" overview-removed \";\n"
+                          "      elem.className +=\" overview-removed \";\n"
                           "      window.webkit.messageHandlers.overview.postMessage(elem.href);\n"
                           "    }\n"
                           "  </script>\n"
@@ -454,14 +457,14 @@ history_service_query_urls_cb (EphyHistoryService     *history,
                           "<body>\n",
                           lang, lang,
                           ((gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) ? "rtl" : "ltr"),
-                          _("Most Visited"));
+                          _(OVERVIEW_PAGE_TITLE));
   g_free (lang);
 
   if (g_list_length (urls) == 0 || !success) {
     GtkIconInfo *icon_info;
 
     icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
-                                            "web-browser-symbolic",
+                                            "org.gnome.Epiphany-symbolic",
                                             128,
                                             0);
     g_string_append_printf (data_str,
@@ -535,7 +538,7 @@ ephy_about_handler_handle_html_overview (EphyAboutHandler       *handler,
   EphyHistoryService *history;
   EphyHistoryQuery *query;
 
-  history = EPHY_HISTORY_SERVICE (ephy_embed_shell_get_global_history_service (ephy_embed_shell_get_default ()));
+  history = ephy_embed_shell_get_global_history_service (ephy_embed_shell_get_default ());
   query = ephy_history_query_new_for_overview ();
   ephy_history_service_query_urls (history, query, NULL,
                                    (EphyHistoryJobCallback)history_service_query_urls_cb,
@@ -575,7 +578,7 @@ ephy_about_handler_handle_incognito (EphyAboutHandler       *handler,
                           gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL ? "rtl" : "ltr",
                           _("Private Browsing"),
                           _("Private Browsing"),
-                          _("You are currently browsing <em>incognito</em>. Pages viewed in this "
+                          _("You are currently browsing incognito. Pages viewed in this "
                             "mode will not show up in your browsing history and all stored "
                             "information will be cleared when you close the window. Files you "
                             "download will be kept."),
@@ -619,7 +622,7 @@ ephy_about_handler_handle_request (EphyAboutHandler       *handler,
     handled = ephy_about_handler_handle_memory (handler, request);
   else if (!g_strcmp0 (path, "epiphany"))
     handled = ephy_about_handler_handle_epiphany (handler, request);
-  else if (!g_strcmp0 (path, "applications"))
+  else if (!g_strcmp0 (path, "applications") && !ephy_is_running_inside_flatpak ())
     handled = ephy_about_handler_handle_applications (handler, request);
   else if (!g_strcmp0 (path, "overview"))
     handled = ephy_about_handler_handle_html_overview (handler, request);
