@@ -3,27 +3,32 @@
  *  Copyright © 2000-2003 Marco Pesenti Gritti
  *  Copyright © 2011 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EPHY_EMBED_SHELL_H
-#define EPHY_EMBED_SHELL_H
+#pragma once
 
 #include <webkit2/webkit2.h>
+
 #include "ephy-downloads-manager.h"
+#include "ephy-encodings.h"
+#include "ephy-gsb-service.h"
 #include "ephy-history-service.h"
-#include "ephy-hosts-manager.h"
+#include "ephy-permissions-manager.h"
+#include "ephy-search-engine-manager.h"
 
 G_BEGIN_DECLS
 
@@ -42,9 +47,6 @@ typedef enum
   EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER
 } EphyEmbedShellMode;
 
-#define EPHY_EMBED_SHELL_MODE_HAS_PRIVATE_PROFILE(mode) \
-  (mode == EPHY_EMBED_SHELL_MODE_PRIVATE || mode == EPHY_EMBED_SHELL_MODE_INCOGNITO)
-
 struct _EphyEmbedShellClass
 {
   GtkApplicationClass parent_class;
@@ -54,8 +56,10 @@ struct _EphyEmbedShellClass
 
 EphyEmbedShell    *ephy_embed_shell_get_default                (void);
 WebKitWebContext  *ephy_embed_shell_get_web_context            (EphyEmbedShell   *shell);
-GObject           *ephy_embed_shell_get_global_history_service (EphyEmbedShell   *shell);
-GObject           *ephy_embed_shell_get_encodings              (EphyEmbedShell   *shell);
+EphyHistoryService
+                  *ephy_embed_shell_get_global_history_service (EphyEmbedShell   *shell);
+EphyGSBService    *ephy_embed_shell_get_global_gsb_service     (EphyEmbedShell   *shell);
+EphyEncodings     *ephy_embed_shell_get_encodings              (EphyEmbedShell   *shell);
 void               ephy_embed_shell_restored_window            (EphyEmbedShell   *shell);
 void               ephy_embed_shell_set_page_setup             (EphyEmbedShell   *shell,
                                                                 GtkPageSetup     *page_setup);
@@ -68,17 +72,19 @@ gboolean           ephy_embed_shell_launch_handler             (EphyEmbedShell
                                                                 GFile            *file,
                                                                 const char       *mime_type,
                                                                 guint32           user_time);
+void               ephy_embed_shell_add_app_related_uri        (EphyEmbedShell   *shell,
+                                                                const char       *uri);
+gboolean           ephy_embed_shell_uri_looks_related_to_app   (EphyEmbedShell   *shell,
+                                                                const char       *uri);
 void               ephy_embed_shell_clear_cache                (EphyEmbedShell   *shell);
 void               ephy_embed_shell_set_thumbnail_path         (EphyEmbedShell   *shell,
                                                                 const char       *url,
-                                                                time_t            mtime,
                                                                 const char       *path);
 void               ephy_embed_shell_schedule_thumbnail_update  (EphyEmbedShell   *shell,
                                                                 EphyHistoryURL   *url);
 WebKitUserContentManager *ephy_embed_shell_get_user_content_manager (EphyEmbedShell *shell);
 EphyDownloadsManager     *ephy_embed_shell_get_downloads_manager    (EphyEmbedShell *shell);
-EphyHostsManager         *ephy_embed_shell_get_hosts_manager        (EphyEmbedShell *shell);
+EphyPermissionsManager   *ephy_embed_shell_get_permissions_manager  (EphyEmbedShell *shell);
+EphySearchEngineManager  *ephy_embed_shell_get_search_engine_manager (EphyEmbedShell *shell);
 
 G_END_DECLS
-
-#endif /* !EPHY_EMBED_SHELL_H */
