@@ -1,20 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8; -*- */
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  *  Copyright © 2004 Tommi Komulainen
  *  Copyright © 2004, 2005 Christian Persch
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of Epiphany.
+ *
+ *  Epiphany is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -132,32 +134,6 @@ clear_status (EphyFindToolbar *toolbar)
   webkit_find_controller_search_finish (toolbar->controller);
 }
 
-/* Code adapted from gtktreeview.c:gtk_tree_view_key_press() and
- * gtk_tree_view_real_start_interactive_seach()
- */
-static gboolean
-tab_search_key_press_cb (WebKitWebView   *web_view,
-                         GdkEventKey     *event,
-                         EphyFindToolbar *toolbar)
-{
-  GtkWidget *widget = (GtkWidget *)toolbar;
-
-  g_return_val_if_fail (event != NULL, FALSE);
-
-  /* check for / and ' which open the find toolbar in text resp. link mode */
-  if (gtk_search_bar_get_search_mode (GTK_SEARCH_BAR (widget)) == FALSE) {
-    if (event->keyval == GDK_KEY_slash) {
-      ephy_find_toolbar_open (toolbar, FALSE, TRUE);
-      return TRUE;
-    } else if (event->keyval == GDK_KEY_apostrophe) {
-      ephy_find_toolbar_open (toolbar, TRUE, TRUE);
-      return TRUE;
-    }
-  }
-
-  return FALSE;
-}
-
 static void
 real_find (EphyFindToolbar  *toolbar,
            EphyFindDirection direction)
@@ -560,10 +536,6 @@ ephy_find_toolbar_set_web_view (EphyFindToolbar *toolbar,
                       toolbar);
 
     clear_status (toolbar);
-
-    g_signal_connect_object (EPHY_WEB_VIEW (web_view), "search-key-press",
-                             G_CALLBACK (tab_search_key_press_cb),
-                             toolbar, 0);
   }
 }
 
@@ -584,7 +556,7 @@ ephy_find_toolbar_open (EphyFindToolbar *toolbar,
                         gboolean         links_only,
                         gboolean         typing_ahead)
 {
-  g_return_if_fail (toolbar->web_view != NULL);
+  g_assert (toolbar->web_view != NULL);
 
   toolbar->typing_ahead = typing_ahead;
   toolbar->links_only = links_only;
