@@ -1,48 +1,50 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* vim: set sw=2 ts=2 sts=2 et: */
 /*
  *  Copyright © 2008 Gustavo Noronha Silva
  *  Copyright © 2012 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
-#error "Only <epiphany/epiphany.h> can be included directly."
-#endif
-
-#ifndef EPHY_WEB_VIEW_H
-#define EPHY_WEB_VIEW_H
+#pragma once
 
 #include <webkit2/webkit2.h>
 
+#include "ephy-embed-shell.h"
+#include "ephy-history-types.h"
 #include "ephy-security-levels.h"
 
 G_BEGIN_DECLS
 
-#define EPHY_TYPE_WEB_VIEW         (ephy_web_view_get_type ())
-#define EPHY_WEB_VIEW(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_WEB_VIEW, EphyWebView))
-#define EPHY_WEB_VIEW_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_WEB_VIEW, EphyWebViewClass))
-#define EPHY_IS_WEB_VIEW(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_WEB_VIEW))
-#define EPHY_IS_WEB_VIEW_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_WEB_VIEW))
-#define EPHY_WEB_VIEW_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_WEB_VIEW, EphyWebViewClass))
+#define EPHY_TYPE_WEB_VIEW (ephy_web_view_get_type ())
 
-typedef struct _EphyWebViewClass  EphyWebViewClass;
-typedef struct _EphyWebView    EphyWebView;
-typedef struct _EphyWebViewPrivate  EphyWebViewPrivate;
+G_DECLARE_FINAL_TYPE (EphyWebView, ephy_web_view, EPHY, WEB_VIEW, WebKitWebView)
+
+#define EPHY_WEB_VIEW_NON_SEARCH_REGEX  "(" \
+                                        "^[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9](:[0-9]+)?.*$|" \
+                                        "^::[0-9a-f:]*$|" \
+                                        "^[0-9a-f:]+:[0-9a-f:]*$|" \
+                                        "^https?://[^/\\.[:space:]]+.*$|" \
+                                        "^about:.*$|" \
+                                        "^data:.*$|" \
+                                        "^file:.*$" \
+                                        ")"
+
+#define EPHY_WEB_VIEW_DOMAIN_REGEX "^localhost(\\.[^[:space:]]+)?(:\\d+)?(:[0-9]+)?(/.*)?$|" \
+                                   "^[^\\.[:space:]]+\\.[^\\.[:space:]]+.*$|"
 
 typedef enum
 {
@@ -59,51 +61,14 @@ typedef enum
 } EphyWebViewDocumentType;
 
 typedef enum {
+  EPHY_WEB_VIEW_ERROR_PAGE_NONE,
   EPHY_WEB_VIEW_ERROR_PAGE_NETWORK_ERROR,
   EPHY_WEB_VIEW_ERROR_PAGE_CRASH,
   EPHY_WEB_VIEW_ERROR_PROCESS_CRASH,
-  EPHY_WEB_VIEW_ERROR_INVALID_TLS_CERTIFICATE
+  EPHY_WEB_VIEW_ERROR_INVALID_TLS_CERTIFICATE,
+  EPHY_WEB_VIEW_ERROR_UNSAFE_BROWSING
 } EphyWebViewErrorPage;
 
-struct _EphyWebView
-{
-  WebKitWebView parent;
-
-  /*< private >*/
-  EphyWebViewPrivate *priv;
-};
-
-struct _EphyWebViewClass
-{
-  WebKitWebViewClass parent_class;
-
-  /* Signals */
-  void   (* feed_link)          (EphyWebView *view,
-                                 const char *type,
-                                 const char *title,
-                                 const char *address);
-  void   (* search_link)        (EphyWebView *view,
-                                 const char *type,
-                                 const char *title,
-                                 const char *address);
-  void   (* popup_blocked)      (EphyWebView *view,
-                                 const char *address,
-                                 const char *target,
-                                 const char *features);
-  void   (* content_blocked)    (EphyWebView *view,
-                                 const char *uri);
-  gboolean (* modal_alert)      (EphyWebView *view);
-  void   (* modal_alert_closed) (EphyWebView *view);
-  void   (* new_window)         (EphyWebView *view,
-                                 EphyWebView *new_view);
-  gboolean (* search_key_press) (EphyWebView *view,
-                                 GdkEventKey *event);
-  void   (* new_document_now)   (EphyWebView *view,
-                                 const char *uri);
-  void   (* loading_homepage)   (EphyWebView *view);
-};
-
-GType                      ephy_web_view_get_type                 (void);
 GType                      ephy_web_view_chrome_get_type          (void);
 GType                      ephy_web_view_security_level_get_type  (void);
 GtkWidget *                ephy_web_view_new                      (void);
@@ -126,6 +91,9 @@ void                       ephy_web_view_set_security_level       (EphyWebView
 const char *               ephy_web_view_get_typed_address        (EphyWebView               *view);
 void                       ephy_web_view_set_typed_address        (EphyWebView               *view,
                                                                    const char                *address);
+gboolean            ephy_web_view_get_should_bypass_safe_browsing (EphyWebView               *view);
+void                ephy_web_view_set_should_bypass_safe_browsing (EphyWebView               *view,
+                                                                   gboolean                   bypass_safe_browsing);
 gboolean                   ephy_web_view_get_is_blank             (EphyWebView               *view);
 gboolean                   ephy_web_view_is_overview              (EphyWebView               *view);
 void                       ephy_web_view_has_modified_forms       (EphyWebView               *view,
@@ -137,26 +105,28 @@ gboolean                  ephy_web_view_has_modified_forms_finish (EphyWebView
                                                                    GError                   **error);
 void                       ephy_web_view_get_security_level       (EphyWebView               *view,
                                                                    EphySecurityLevel         *level,
+                                                                   const char               **address,
                                                                    GTlsCertificate          **certificate,
                                                                    GTlsCertificateFlags      *errors);
 void                       ephy_web_view_print                    (EphyWebView               *view);
 const char *               ephy_web_view_get_address              (EphyWebView               *view);
+const char *             ephy_web_view_get_last_committed_address (EphyWebView               *view);
 const char *               ephy_web_view_get_display_address      (EphyWebView               *view);
 void                       ephy_web_view_set_placeholder          (EphyWebView               *view,
                                                                    const char                *uri,
                                                                    const char                *title);
-
+EphyWebViewErrorPage       ephy_web_view_get_error_page           (EphyWebView               *view);
 void                       ephy_web_view_load_error_page          (EphyWebView               *view,
                                                                    const char                *uri,
                                                                    EphyWebViewErrorPage       page,
-                                                                   GError                    *error);
+                                                                   GError                    *error,
+                                                                   gpointer                   user_data);
 void                       ephy_web_view_get_best_web_app_icon    (EphyWebView               *view,
                                                                    GCancellable              *cancellable,
                                                                    GAsyncReadyCallback        callback,
                                                                    gpointer                   user_data);
 gboolean               ephy_web_view_get_best_web_app_icon_finish (EphyWebView               *view,
                                                                    GAsyncResult              *result,
-                                                                   gboolean                  *icon_result,
                                                                    char                     **icon_uri,
                                                                    GdkRGBA                   *icon_color,
                                                                    GError                   **error);
@@ -168,6 +138,17 @@ char                      *ephy_web_view_get_web_app_title_finish (EphyWebView
                                                                    GAsyncResult              *result,
                                                                    GError                   **error);
 
-G_END_DECLS
+void                       ephy_web_view_set_visit_type           (EphyWebView *view, 
+                                                                   EphyHistoryPageVisitType visit_type);
+EphyHistoryPageVisitType   ephy_web_view_get_visit_type           (EphyWebView *view);
+void                       ephy_web_view_popups_manager_reset     (EphyWebView               *view);
+void                       ephy_web_view_save                     (EphyWebView               *view,
+                                                                   const char                *uri);
+void                       ephy_web_view_load_homepage            (EphyWebView               *view);
+void                       ephy_web_view_load_new_tab_page        (EphyWebView               *view);
 
-#endif
+char *                     ephy_web_view_create_web_application   (EphyWebView               *view,
+                                                                   const char                *title,
+                                                                   GdkPixbuf                 *icon);
+
+G_END_DECLS
