@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2; -*- */
-/* vim: set sw=2 ts=2 sts=2 et: */
 /*
  *  Copyright © 2011 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -295,7 +296,7 @@ ephy_history_service_find_host_rows (EphyHistoryService *self, EphyHistoryQuery
     return NULL;
   }
   if (query->from > 0) {
-    if (ephy_sqlite_statement_bind_int (statement, i++, (int)query->from, &error) == FALSE) {
+    if (ephy_sqlite_statement_bind_int64 (statement, i++, query->from, &error) == FALSE) {
       g_warning ("Could not build hosts table query statement: %s", error->message);
       g_error_free (error);
       g_object_unref (statement);
@@ -303,7 +304,7 @@ ephy_history_service_find_host_rows (EphyHistoryService *self, EphyHistoryQuery
     }
   }
   if (query->to > 0) {
-    if (ephy_sqlite_statement_bind_int (statement, i++, (int)query->to, &error) == FALSE) {
+    if (ephy_sqlite_statement_bind_int64 (statement, i++, query->to, &error) == FALSE) {
       g_warning ("Could not build hosts table query statement: %s", error->message);
       g_error_free (error);
       g_object_unref (statement);
@@ -363,7 +364,7 @@ get_hostname_and_locations (const gchar *url, gchar **hostname)
     char *location;
     char *tmp;
 
-    if (g_str_equal (scheme, "https")) {
+    if (!strcmp (scheme, "https")) {
       /* If scheme is https, we still fake http. */
       location = g_strconcat ("http://", *hostname, "/", NULL);
       host_locations = g_list_append (host_locations, location);
