@@ -23,8 +23,9 @@
 
 #include "ephy-history-service-private.h"
 #include "ephy-history-types.h"
-#include "ephy-history-type-builtins.h"
+#include "ephy-lib-type-builtins.h"
 #include "ephy-sqlite-connection.h"
+#include "ephy-sync-utils.h"
 
 #include <errno.h>
 #include <glib.h>
@@ -37,7 +38,6 @@ typedef enum {
   SET_URL_TITLE,
   SET_URL_ZOOM_LEVEL,
   SET_URL_HIDDEN,
-  SET_URL_THUMBNAIL_TIME,
   ADD_VISIT,
   ADD_VISITS,
   DELETE_URLS,
@@ -221,9 +221,8 @@ ephy_history_service_class_init (EphyHistoryServiceClass *klass)
                   G_SIGNAL_RUN_LAST,
                   0, NULL, NULL, NULL,
                   G_TYPE_NONE,
-                  2,
-                  G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
-                  EPHY_TYPE_HISTORY_PAGE_VISIT_TYPE);
+                  1,
+                  G_TYPE_POINTER | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 /**
  * EphyHistoryService::urls-visited:
@@ -268,7 +267,7 @@ ephy_history_service_class_init (EphyHistoryServiceClass *klass)
                   0, NULL, NULL, NULL,
                   G_TYPE_NONE,
                   1,
-                  G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
+                  G_TYPE_POINTER | G_SIGNAL_TYPE_STATIC_SCOPE);
 
   signals[HOST_DELETED] =
     g_signal_new ("host-deleted",
@@ -391,23 +390,6 @@ ephy_history_service_commit_transaction (EphyHistoryService *self)
   }
 }
 
-static void
-ephy_history_service_enable_foreign_keys (EphyHistoryService *self)
-{
-  GError *error = NULL;
-
-  if (self->history_database == NULL)
-    return;
-
-  ephy_sqlite_connection_execute (self->history_database,
-                                  "PRAGMA foreign_keys = ON", &error);
-
-  if (error) {
-    g_warning ("Could not enable foreign keys pragma: %s", error->message);
-    g_error_free (error);
-  }
-}
-
 static gboolean
 ephy_history_service_open_database_connections (EphyHistoryService *self)
 {
@@ -419,8 +401,9 @@ ephy_history_service_open_database_connections (EphyHistoryService *self)
     g_object_unref (self->history_database);
 
   self->history_database = ephy_sqlite_connection_new (self->read_only ? EPHY_SQLITE_CONNECTION_MODE_READ_ONLY
-                                                                       : EPHY_SQLITE_CONNECTION_MODE_READWRITE);
-  ephy_sqlite_connection_open (self->history_database, self->history_filename, &error);
+                                                                       : EPHY_SQLITE_CONNECTION_MODE_READWRITE,
+                                                       self->history_filename);
+  ephy_sqlite_connection_open (self->history_database, &error);
   if (error) {
     g_object_unref (self->history_database);
     self->history_database = NULL;
@@ -434,10 +417,10 @@ ephy_history_service_open_database_connections (EphyHistoryService *self)
     }
     g_error_free (error);
     return FALSE;
+  } else {
+    ephy_sqlite_connection_enable_foreign_keys (self->history_database);
   }
 
-  ephy_history_service_enable_foreign_keys (self);
-
   return self->read_only ||
           (ephy_history_service_initialize_hosts_table (self) &&
            ephy_history_service_initialize_urls_table (self) &&
@@ -575,11 +558,16 @@ ephy_history_service_execute_add_visit_helper (EphyHistoryService *self, EphyHis
   visit->url->host->visit_count++;
   ephy_history_service_update_host_row (self, visit->url->host);
 
-  /* A NULL return here means that the URL does not yet exist in the database */
+  /* A NULL return here means that the URL does not yet exist in the database.
+   * This overwrites visit->url so we have to test the sync id against NULL on
+   * both branches. */
   if (ephy_history_service_get_url_row (self, visit->url->url, visit->url) == NULL) {
     visit->url->last_visit_time = visit->visit_time;
     visit->url->visit_count = 1;
 
+    if (!visit->url->sync_id)
+      visit->url->sync_id = ephy_sync_utils_get_random_sync_id ();
+
     ephy_history_service_add_url_row (self, visit->url);
 
     if (visit->url->id == -1) {
@@ -592,9 +580,15 @@ ephy_history_service_execute_add_visit_helper (EphyHistoryService *self, EphyHis
     if (visit->visit_time > visit->url->last_visit_time)
       visit->url->last_visit_time = visit->visit_time;
 
+    if (!visit->url->sync_id)
+      visit->url->sync_id = ephy_sync_utils_get_random_sync_id ();
+
     ephy_history_service_update_url_row (self, visit->url);
   }
 
+  if (visit->url->notify_visit)
+    g_signal_emit (self, signals[VISIT_URL], 0, visit->url);
+
   ephy_history_service_add_visit_row (self, visit);
   return visit->id != -1;
 }
@@ -680,8 +674,8 @@ ephy_history_service_add_visit (EphyHistoryService *self, EphyHistoryPageVisit *
 {
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (visit != NULL);
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (visit != NULL);
 
   message = ephy_history_service_message_new (self, ADD_VISIT,
                                               ephy_history_page_visit_copy (visit),
@@ -695,8 +689,8 @@ ephy_history_service_add_visits (EphyHistoryService *self, GList *visits, GCance
 {
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (visits != NULL);
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (visits != NULL);
 
   message = ephy_history_service_message_new (self, ADD_VISITS,
                                               ephy_history_page_visit_list_copy (visits),
@@ -710,7 +704,7 @@ ephy_history_service_find_visits_in_time (EphyHistoryService *self, gint64 from,
 {
   EphyHistoryQuery *query;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
 
   query = ephy_history_query_new ();
   query->from = from;
@@ -725,8 +719,8 @@ ephy_history_service_query_visits (EphyHistoryService *self, EphyHistoryQuery *q
 {
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (query != NULL);
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (query != NULL);
 
   message = ephy_history_service_message_new (self, QUERY_VISITS,
                                               ephy_history_query_copy (query), (GDestroyNotify)ephy_history_query_free, cancellable, callback, user_data);
@@ -748,8 +742,8 @@ ephy_history_service_query_urls (EphyHistoryService *self, EphyHistoryQuery *que
 {
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (query != NULL);
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (query != NULL);
 
   message = ephy_history_service_message_new (self, QUERY_URLS,
                                               ephy_history_query_copy (query), (GDestroyNotify)ephy_history_query_free,
@@ -765,7 +759,7 @@ ephy_history_service_get_hosts (EphyHistoryService    *self,
 {
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
 
   message = ephy_history_service_message_new (self, GET_HOSTS,
                                               NULL, NULL, cancellable,
@@ -782,7 +776,7 @@ ephy_history_service_query_hosts (EphyHistoryService    *self,
 {
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
 
   message = ephy_history_service_message_new (self, QUERY_HOSTS,
                                               ephy_history_query_copy (query),
@@ -843,10 +837,10 @@ ephy_history_service_set_url_title (EphyHistoryService    *self,
   EphyHistoryURL *url;
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (orig_url != NULL);
-  g_return_if_fail (title != NULL);
-  g_return_if_fail (*title != '\0');
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (orig_url != NULL);
+  g_assert (title != NULL);
+  g_assert (*title != '\0');
 
   url = ephy_history_url_new (orig_url, title, 0, 0, 0);
   message = ephy_history_service_message_new (self, SET_URL_TITLE,
@@ -872,7 +866,7 @@ ephy_history_service_execute_set_url_zoom_level (EphyHistoryService *self,
   host = ephy_history_service_get_host_row_from_url (self, url_string);
   g_free (url_string);
 
-  g_return_val_if_fail (host != NULL, FALSE);
+  g_assert (host != NULL);
 
   host->zoom_level = zoom_level;
   ephy_history_service_update_host_row (self, host);
@@ -891,8 +885,8 @@ ephy_history_service_set_url_zoom_level (EphyHistoryService    *self,
   EphyHistoryServiceMessage *message;
   GVariant *variant;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (url != NULL);
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (url != NULL);
 
   variant = g_variant_new ("(sd)", url, zoom_level);
 
@@ -935,8 +929,8 @@ ephy_history_service_set_url_hidden (EphyHistoryService    *self,
   EphyHistoryServiceMessage *message;
   EphyHistoryURL *url;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (orig_url != NULL);
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (orig_url != NULL);
 
   url = ephy_history_url_new (orig_url, NULL, 0, 0, 0);
   url->hidden = hidden;
@@ -947,49 +941,6 @@ ephy_history_service_set_url_hidden (EphyHistoryService    *self,
   ephy_history_service_send_message (self, message);
 }
 
-static gboolean
-ephy_history_service_execute_set_url_thumbnail_time (EphyHistoryService *self,
-                                                     EphyHistoryURL     *url,
-                                                     gpointer           *result)
-{
-  gint64 thumbnail_time;
-
-  if (self->read_only)
-    return FALSE;
-
-  thumbnail_time = url->thumbnail_time;
-
-  if (ephy_history_service_get_url_row (self, NULL, url) == NULL)
-    return FALSE;
-  else {
-    url->thumbnail_time = thumbnail_time;
-    ephy_history_service_update_url_row (self, url);
-    return TRUE;
-  }
-}
-
-void
-ephy_history_service_set_url_thumbnail_time (EphyHistoryService    *self,
-                                             const char            *orig_url,
-                                             gint64                 thumbnail_time,
-                                             GCancellable          *cancellable,
-                                             EphyHistoryJobCallback callback,
-                                             gpointer               user_data)
-{
-  EphyHistoryURL *url;
-  EphyHistoryServiceMessage *message;
-
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (orig_url != NULL);
-
-  url = ephy_history_url_new (orig_url, NULL, 0, 0, 0);
-  url->thumbnail_time = thumbnail_time;
-  message = ephy_history_service_message_new (self, SET_URL_THUMBNAIL_TIME,
-                                              url, (GDestroyNotify)ephy_history_url_free,
-                                              cancellable, callback, user_data);
-  ephy_history_service_send_message (self, message);
-}
-
 static gboolean
 ephy_history_service_execute_get_url (EphyHistoryService *self,
                                       const gchar        *orig_url,
@@ -1013,8 +964,8 @@ ephy_history_service_get_url (EphyHistoryService    *self,
 {
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (url != NULL);
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (url != NULL);
 
   message = ephy_history_service_message_new (self, GET_URL,
                                               g_strdup (url), g_free,
@@ -1030,7 +981,7 @@ ephy_history_service_execute_get_host_for_url (EphyHistoryService *self,
   EphyHistoryHost *host;
 
   host = ephy_history_service_get_host_row_from_url (self, url);
-  g_return_val_if_fail (host != NULL, FALSE);
+  g_assert (host != NULL);
 
   *result = host;
 
@@ -1046,8 +997,8 @@ ephy_history_service_get_host_for_url (EphyHistoryService    *self,
 {
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (url != NULL);
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (url != NULL);
 
   message = ephy_history_service_message_new (self, GET_HOST_FOR_URL,
                                               g_strdup (url), g_free,
@@ -1058,7 +1009,7 @@ ephy_history_service_get_host_for_url (EphyHistoryService    *self,
 static gboolean
 delete_urls_signal_emit (SignalEmissionContext *ctx)
 {
-  char *url = (char *)ctx->user_data;
+  EphyHistoryURL *url = (EphyHistoryURL *)ctx->user_data;
 
   g_signal_emit (ctx->service, signals[URL_DELETED], 0, url);
 
@@ -1081,12 +1032,14 @@ ephy_history_service_execute_delete_urls (EphyHistoryService *self,
     url = l->data;
     ephy_history_service_delete_url (self, url);
 
-    ctx = signal_emission_context_new (self, g_strdup (url->url),
-                                       (GDestroyNotify)g_free);
-    g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
-                     (GSourceFunc)delete_urls_signal_emit,
-                     ctx,
-                     (GDestroyNotify)signal_emission_context_free);
+    if (url->notify_delete) {
+      ctx = signal_emission_context_new (self, ephy_history_url_copy (url),
+                                         (GDestroyNotify)ephy_history_url_free);
+      g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
+                       (GSourceFunc)delete_urls_signal_emit,
+                       ctx,
+                       (GDestroyNotify)signal_emission_context_free);
+    }
   }
 
   ephy_history_service_delete_orphan_hosts (self);
@@ -1132,22 +1085,13 @@ ephy_history_service_execute_clear (EphyHistoryService *self,
                                     gpointer            pointer,
                                     gpointer           *result)
 {
-  char *journal_filename;
-
   if (self->history_database == NULL ||
       self->read_only)
     return FALSE;
 
   ephy_history_service_commit_transaction (self);
   ephy_sqlite_connection_close (self->history_database);
-
-  if (g_unlink (self->history_filename) == -1)
-    g_warning ("Failed to delete %s: %s", self->history_filename, g_strerror (errno));
-
-  journal_filename = g_strdup_printf ("%s-journal", self->history_filename);
-  if (g_unlink (journal_filename) == -1 && errno != ENOENT)
-    g_warning ("Failed to delete %s: %s", journal_filename, g_strerror (errno));
-  g_free (journal_filename);
+  ephy_sqlite_connection_delete_database (self->history_database);
 
   ephy_history_service_open_database_connections (self);
   ephy_history_service_open_transaction (self);
@@ -1164,8 +1108,8 @@ ephy_history_service_delete_urls (EphyHistoryService    *self,
 {
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (urls != NULL);
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (urls != NULL);
 
   message = ephy_history_service_message_new (self, DELETE_URLS,
                                               ephy_history_url_list_copy (urls), (GDestroyNotify)ephy_history_url_list_free,
@@ -1195,7 +1139,7 @@ ephy_history_service_clear (EphyHistoryService    *self,
 {
   EphyHistoryServiceMessage *message;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
 
   message = ephy_history_service_message_new (self, CLEAR,
                                               NULL, NULL,
@@ -1219,7 +1163,6 @@ static EphyHistoryServiceMethod methods[] = {
   (EphyHistoryServiceMethod)ephy_history_service_execute_set_url_title,
   (EphyHistoryServiceMethod)ephy_history_service_execute_set_url_zoom_level,
   (EphyHistoryServiceMethod)ephy_history_service_execute_set_url_hidden,
-  (EphyHistoryServiceMethod)ephy_history_service_execute_set_url_thumbnail_time,
   (EphyHistoryServiceMethod)ephy_history_service_execute_add_visit,
   (EphyHistoryServiceMethod)ephy_history_service_execute_add_visits,
   (EphyHistoryServiceMethod)ephy_history_service_execute_delete_urls,
@@ -1286,7 +1229,7 @@ ephy_history_service_find_urls (EphyHistoryService *self,
 {
   EphyHistoryQuery *query;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
 
   query = ephy_history_query_new ();
   query->from = from;
@@ -1305,22 +1248,23 @@ ephy_history_service_find_urls (EphyHistoryService *self,
 }
 
 void
-ephy_history_service_visit_url (EphyHistoryService      *self,
-                                const char              *url,
-                                EphyHistoryPageVisitType visit_type)
+ephy_history_service_visit_url (EphyHistoryService       *self,
+                                const char               *url,
+                                const char               *sync_id,
+                                gint64                    visit_time,
+                                EphyHistoryPageVisitType  visit_type,
+                                gboolean                  should_notify)
 {
   EphyHistoryPageVisit *visit;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
-  g_return_if_fail (url != NULL);
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (url != NULL);
+  g_assert (visit_time > 0);
 
-  g_signal_emit (self, signals[VISIT_URL], 0, url, visit_type);
-
-  visit = ephy_history_page_visit_new (url,
-                                       time (NULL),
-                                       visit_type);
-  ephy_history_service_add_visit (self,
-                                  visit, NULL, NULL, NULL);
+  visit = ephy_history_page_visit_new (url, visit_time, visit_type);
+  visit->url->sync_id = g_strdup (sync_id);
+  visit->url->notify_visit = should_notify;
+  ephy_history_service_add_visit (self, visit, NULL, NULL, NULL);
   ephy_history_page_visit_free (visit);
 
   ephy_history_service_queue_urls_visited (self);
@@ -1335,7 +1279,7 @@ ephy_history_service_find_hosts (EphyHistoryService *self,
 {
   EphyHistoryQuery *query;
 
-  g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
+  g_assert (EPHY_IS_HISTORY_SERVICE (self));
 
   query = ephy_history_query_new ();
 
