@@ -33,11 +33,11 @@
 #include "ephy-signal-accumulator.h"
 #include "ephy-title-widget.h"
 #include "ephy-uri-helpers.h"
+#include "gd-two-lines-renderer.h"
 
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <libgd/gd.h>
 #include <string.h>
 #if 0
 /* FIXME: Refactor the DNS prefetch, this is a layering violation */
@@ -134,7 +134,7 @@ ephy_location_entry_title_widget_get_address (EphyTitleWidget *widget)
 {
   EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (widget);
 
-  g_return_val_if_fail (entry, NULL);
+  g_assert (entry);
 
   return gtk_entry_get_text (GTK_ENTRY (widget));
 }
@@ -149,7 +149,7 @@ ephy_location_entry_title_widget_set_address (EphyTitleWidget *widget,
   char *effective_text = NULL, *selection = NULL;
   int start, end;
 
-  g_return_if_fail (widget);
+  g_assert (widget);
 
   /* Setting a new text will clear the clipboard. This makes it impossible
    * to copy&paste from the location entry of one tab into another tab, see
@@ -159,7 +159,7 @@ ephy_location_entry_title_widget_set_address (EphyTitleWidget *widget,
   if (gtk_widget_get_realized (GTK_WIDGET (entry))) {
     clipboard = gtk_widget_get_clipboard (GTK_WIDGET (entry),
                                           GDK_SELECTION_PRIMARY);
-    g_return_if_fail (clipboard != NULL);
+    g_assert (clipboard != NULL);
 
     if (gtk_clipboard_get_owner (clipboard) == G_OBJECT (entry) &&
         gtk_editable_get_selection_bounds (GTK_EDITABLE (entry),
@@ -205,7 +205,7 @@ ephy_location_entry_title_widget_get_security_level (EphyTitleWidget *widget)
 {
   EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (widget);
 
-  g_return_val_if_fail (entry, EPHY_SECURITY_LEVEL_TO_BE_DETERMINED);
+  g_assert (entry);
 
   return entry->security_level;
 }
@@ -218,7 +218,7 @@ ephy_location_entry_title_widget_set_security_level (EphyTitleWidget   *widget,
   EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (widget);
   const char *icon_name;
 
-  g_return_if_fail (entry);
+  g_assert (entry);
 
   icon_name = ephy_security_level_to_icon_name (security_level);
   gtk_entry_set_icon_from_icon_name (GTK_ENTRY (widget),
@@ -270,6 +270,16 @@ ephy_location_entry_get_property (GObject    *object,
   }
 }
 
+static void
+ephy_location_entry_constructed (GObject *object)
+{
+  G_OBJECT_CLASS (ephy_location_entry_parent_class)->constructed (object);
+
+#if GTK_CHECK_VERSION(3, 22, 20)
+  gtk_entry_set_input_hints (GTK_ENTRY (object), GTK_INPUT_HINT_NO_EMOJI);
+#endif
+}
+
 static void
 ephy_location_entry_finalize (GObject *object)
 {
@@ -368,6 +378,7 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 
   object_class->get_property = ephy_location_entry_get_property;
   object_class->set_property = ephy_location_entry_set_property;
+  object_class->constructed = ephy_location_entry_constructed;
   object_class->finalize = ephy_location_entry_finalize;
 
   widget_class->size_allocate = ephy_location_entry_size_allocate;
@@ -600,7 +611,7 @@ entry_paste_and_go_activate_cb (GtkMenuItem       *item,
 {
   GtkClipboard *clipboard;
 
-  clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
+  clipboard = gtk_clipboard_get_default (gdk_display_get_default ());
   gtk_clipboard_request_text (clipboard,
                               (GtkClipboardTextReceivedFunc)paste_received,
                               entry);
@@ -662,6 +673,7 @@ entry_populate_popup_cb (GtkEntry          *entry,
     if (GTK_IS_SEPARATOR_MENU_ITEM (item->data))
       sep++;
   }
+  g_list_free (children);
 
   gtk_menu_shell_insert (GTK_MENU_SHELL (menu), clear_menuitem, pos - 1);
 
@@ -676,6 +688,7 @@ entry_populate_popup_cb (GtkEntry          *entry,
     }
   }
   g_assert (paste_menuitem != NULL);
+  g_list_free (children);
 
   g_signal_connect (paste_and_go_menuitem, "activate",
                     G_CALLBACK (entry_paste_and_go_activate_cb), lentry);
@@ -705,16 +718,14 @@ entry_populate_popup_cb (GtkEntry          *entry,
 }
 
 static gboolean
-icon_button_press_event_cb (GtkWidget           *entry,
-                            GtkEntryIconPosition position,
-                            GdkEventButton      *event,
-                            EphyLocationEntry   *lentry)
+icon_button_icon_press_event_cb (GtkWidget           *entry,
+                                 GtkEntryIconPosition position,
+                                 GdkEventButton      *event,
+                                 EphyLocationEntry   *lentry)
 {
-  guint state = event->state & gtk_accelerator_get_default_mod_mask ();
-
-  if (event->type == GDK_BUTTON_PRESS &&
-      event->button == 1 &&
-      state == 0 /* left */) {
+  if (((event->type == GDK_BUTTON_PRESS &&
+        event->button == 1) ||
+       (event->type == GDK_TOUCH_BEGIN))) {
     if (position == GTK_ENTRY_ICON_PRIMARY) {
       GdkRectangle lock_position;
       gtk_entry_get_icon_area (GTK_ENTRY (entry), GTK_ENTRY_ICON_PRIMARY, &lock_position);
@@ -740,7 +751,7 @@ ephy_location_entry_construct_contents (EphyLocationEntry *lentry)
                                      "non-starred-symbolic");
 
   g_object_connect (entry,
-                    "signal::icon-press", G_CALLBACK (icon_button_press_event_cb), lentry,
+                    "signal::icon-press", G_CALLBACK (icon_button_icon_press_event_cb), lentry,
                     "signal::populate-popup", G_CALLBACK (entry_populate_popup_cb), lentry,
                     "signal::key-press-event", G_CALLBACK (entry_key_press_cb), lentry,
                     "signal::changed", G_CALLBACK (editable_changed_cb), lentry,
@@ -1180,7 +1191,7 @@ ephy_location_entry_set_bookmark_icon_state (EphyLocationEntry
 {
   GtkStyleContext *context;
 
-  g_return_if_fail (EPHY_IS_LOCATION_ENTRY (entry));
+  g_assert (EPHY_IS_LOCATION_ENTRY (entry));
 
   context = gtk_widget_get_style_context (GTK_WIDGET (entry));
 
@@ -1232,8 +1243,8 @@ void
 ephy_location_entry_set_add_bookmark_popover (EphyLocationEntry *entry,
                                               GtkPopover        *popover)
 {
-  g_return_if_fail (EPHY_IS_LOCATION_ENTRY (entry));
-  g_return_if_fail (GTK_IS_POPOVER (popover));
+  g_assert (EPHY_IS_LOCATION_ENTRY (entry));
+  g_assert (GTK_IS_POPOVER (popover));
 
   entry->add_bookmark_popover = popover;
 }
