@@ -39,14 +39,13 @@ struct _EphyBookmark {
   GSequence   *tags;
   gint64       time_added;
 
-  /* Firefox Sync specific fields.
-   * Time modified timestamp must be double to match server's precision. */
+  /* Firefox Sync specific fields. */
   char        *id;
   char        *type;
   char        *parent_id;
   char        *parent_name;
   gboolean     load_in_sidebar;
-  double       server_time_modified;
+  gint64       server_time_modified;
 };
 
 static void json_serializable_iface_init (JsonSerializableIface *iface);
@@ -100,9 +99,10 @@ ephy_bookmark_set_property (GObject      *object,
       ephy_bookmark_set_url (self, g_value_get_string (value));
       break;
     case PROP_TAGS:
-      if (self->tags != NULL)
-        g_sequence_free (self->tags);
+      g_sequence_free (self->tags);
       self->tags = g_value_get_pointer (value);
+      if (!self->tags)
+        self->tags = g_sequence_new (g_free);
       break;
     case PROP_TYPE:
       g_free (self->type);
@@ -177,8 +177,7 @@ ephy_bookmark_finalize (GObject *object)
   g_free (self->title);
   g_free (self->id);
 
-  if (self->tags)
-    g_sequence_free (self->tags);
+  g_sequence_free (self->tags);
 
   G_OBJECT_CLASS (ephy_bookmark_parent_class)->finalize (object);
 }
@@ -280,6 +279,7 @@ ephy_bookmark_class_init (EphyBookmarkClass *klass)
 static void
 ephy_bookmark_init (EphyBookmark *self)
 {
+  self->tags = g_sequence_new (g_free);
 }
 
 EphyBookmark *
@@ -305,7 +305,7 @@ void
 ephy_bookmark_set_time_added (EphyBookmark *self,
                               gint64        time_added)
 {
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
+  g_assert (EPHY_IS_BOOKMARK (self));
   g_assert (time_added >= 0);
 
   self->time_added = time_added;
@@ -314,7 +314,7 @@ ephy_bookmark_set_time_added (EphyBookmark *self,
 gint64
 ephy_bookmark_get_time_added (EphyBookmark *self)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), 0);
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   return self->time_added;
 }
@@ -323,7 +323,7 @@ ephy_bookmark_get_time_added (EphyBookmark *self)
 void
 ephy_bookmark_set_url (EphyBookmark *self, const char *url)
 {
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   g_free (self->url);
   self->url = g_strdup (url);
@@ -332,7 +332,7 @@ ephy_bookmark_set_url (EphyBookmark *self, const char *url)
 const char *
 ephy_bookmark_get_url (EphyBookmark *self)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   return self->url;
 }
@@ -340,7 +340,7 @@ ephy_bookmark_get_url (EphyBookmark *self)
 void
 ephy_bookmark_set_title (EphyBookmark *self, const char *title)
 {
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   g_free (self->title);
   self->title = g_strdup (title);
@@ -350,7 +350,7 @@ ephy_bookmark_set_title (EphyBookmark *self, const char *title)
 const char *
 ephy_bookmark_get_title (EphyBookmark *bookmark)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (bookmark), NULL);
+  g_assert (EPHY_IS_BOOKMARK (bookmark));
 
   return bookmark->title;
 }
@@ -359,8 +359,8 @@ void
 ephy_bookmark_set_id (EphyBookmark *self,
                       const char   *id)
 {
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
-  g_return_if_fail (id != NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
+  g_assert (id != NULL);
 
   g_free (self->id);
   self->id = g_strdup (id);
@@ -369,7 +369,7 @@ ephy_bookmark_set_id (EphyBookmark *self,
 const char *
 ephy_bookmark_get_id (EphyBookmark *self)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   return self->id;
 }
@@ -381,7 +381,7 @@ ephy_bookmark_set_is_uploaded (EphyBookmark *self,
 
   /* FIXME: This is no longer used for Firefox Sync, but bookmarks import/export
    * expects it. We need to delete it and write a migrator for bookmarks. */
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
+  g_assert (EPHY_IS_BOOKMARK (self));
 }
 
 gboolean
@@ -389,7 +389,7 @@ ephy_bookmark_is_uploaded (EphyBookmark *self)
 {
   /* FIXME: This is no longer used for Firefox Sync, but bookmarks import/export
    * expects it. We need to delete it and write a migrator for bookmarks. */
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), FALSE);
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   return FALSE;
 }
@@ -401,8 +401,8 @@ ephy_bookmark_add_tag (EphyBookmark *self,
   GSequenceIter *tag_iter;
   GSequenceIter *prev_tag_iter;
 
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
-  g_return_if_fail (tag != NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
+  g_assert (tag != NULL);
 
   tag_iter = g_sequence_search (self->tags,
                                 (gpointer)tag,
@@ -423,8 +423,8 @@ ephy_bookmark_remove_tag (EphyBookmark *self,
 {
   GSequenceIter *tag_iter;
 
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
-  g_return_if_fail (tag != NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
+  g_assert (tag != NULL);
 
   tag_iter = g_sequence_lookup (self->tags,
                                 (gpointer)tag,
@@ -442,8 +442,8 @@ ephy_bookmark_has_tag (EphyBookmark *self, const char *tag)
 {
   GSequenceIter *tag_iter;
 
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), FALSE);
-  g_return_val_if_fail (tag != NULL, FALSE);
+  g_assert (EPHY_IS_BOOKMARK (self));
+  g_assert (tag != NULL);
 
   tag_iter = g_sequence_lookup (self->tags,
                                 (gpointer)tag,
@@ -456,7 +456,8 @@ ephy_bookmark_has_tag (EphyBookmark *self, const char *tag)
 GSequence *
 ephy_bookmark_get_tags (EphyBookmark *self)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
+  g_assert (self->tags);
 
   return self->tags;
 }
@@ -520,16 +521,17 @@ serializable_serialize_property (JsonSerializable *serializable,
                                  const GValue     *value,
                                  GParamSpec       *pspec)
 {
-  JsonNode *node = NULL;
+  if (G_VALUE_HOLDS_STRING (value) && g_value_get_string (value) == NULL) {
+    JsonNode *node = json_node_new (JSON_NODE_VALUE);
+    json_node_set_string (node, "");
+    return node;
+  }
 
   if (g_strcmp0 (name, "tags") == 0) {
-    GSequence *tags;
+    JsonNode *node = json_node_new (JSON_NODE_ARRAY);
+    JsonArray *array = json_array_new ();
+    GSequence *tags = g_value_get_pointer (value);
     GSequenceIter *iter;
-    JsonArray *array;
-
-    node = json_node_new (JSON_NODE_ARRAY);
-    array = json_array_new ();
-    tags = g_value_get_pointer (value);
 
     if (tags != NULL) {
       for (iter = g_sequence_get_begin_iter (tags);
@@ -540,13 +542,15 @@ serializable_serialize_property (JsonSerializable *serializable,
     }
 
     json_node_set_array (node, array);
-  } else if (!g_strcmp0 (name, "time-added")) {
-    /* This is not a Firefox bookmark property, skip it.  */
-  } else {
-    node = json_serializable_default_serialize_property (serializable, name, value, pspec);
+
+    return node;
   }
 
-  return node;
+  /* This is not a Firefox bookmark property, skip it. */
+  if (!g_strcmp0 (name, "time-added"))
+    return NULL;
+
+  return json_serializable_default_serialize_property (serializable, name, value, pspec);
 }
 
 static gboolean
@@ -556,14 +560,15 @@ serializable_deserialize_property (JsonSerializable *serializable,
                                    GParamSpec       *pspec,
                                    JsonNode         *node)
 {
-  if (g_strcmp0 (name, "tags") == 0) {
-    GSequence *tags;
-    JsonArray *array;
-    const char *tag;
+  if (G_VALUE_HOLDS_STRING (value) && JSON_NODE_HOLDS_NULL (node)) {
+    g_value_set_string (value, "");
+    return TRUE;
+  }
 
-    g_assert (JSON_NODE_HOLDS_ARRAY (node));
-    array = json_node_get_array (node);
-    tags = g_sequence_new (g_free);
+  if (g_strcmp0 (name, "tags") == 0) {
+    GSequence *tags = g_sequence_new (g_free);
+    JsonArray *array = json_node_get_array (node);
+    const char *tag;
 
     for (gsize i = 0; i < json_array_get_length (array); i++) {
       tag = json_node_get_string (json_array_get_element (array, i));
@@ -592,7 +597,7 @@ synchronizable_get_id (EphySynchronizable *synchronizable)
   return ephy_bookmark_get_id (EPHY_BOOKMARK (synchronizable));
 }
 
-static double
+static gint64
 synchronizable_get_server_time_modified (EphySynchronizable *synchronizable)
 {
   return EPHY_BOOKMARK (synchronizable)->server_time_modified;
@@ -600,7 +605,7 @@ synchronizable_get_server_time_modified (EphySynchronizable *synchronizable)
 
 static void
 synchronizable_set_server_time_modified (EphySynchronizable *synchronizable,
-                                         double              server_time_modified)
+                                         gint64              server_time_modified)
 {
   EPHY_BOOKMARK (synchronizable)->server_time_modified = server_time_modified;
 }
