@@ -4,18 +4,20 @@
  *  Copyright © 2003, 2004, 2005 Christian Persch
  *  Copyright © 2010, 2012 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -26,9 +28,11 @@
 #include "ephy-embed-container.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed-utils.h"
+#include "ephy-location-controller.h"
 #include "ephy-prefs.h"
-#include "ephy-private.h"
 #include "ephy-settings.h"
+#include "ephy-shell.h"
+#include "ephy-window.h"
 
 #include <gtk/gtk.h>
 
@@ -40,26 +44,6 @@ struct _EphyLockdown {
 
 G_DEFINE_TYPE (EphyLockdown, ephy_lockdown, G_TYPE_OBJECT)
 
-static int
-find_name (GtkActionGroup *action_group,
-           const char     *name)
-{
-  return g_strcmp0 (gtk_action_group_get_name (action_group), name);
-}
-
-static GtkActionGroup *
-find_action_group (GtkUIManager *manager,
-                   const char   *name)
-{
-  GList *list, *element;
-
-  list = gtk_ui_manager_get_action_groups (manager);
-  element = g_list_find_custom (list, name, (GCompareFunc)find_name);
-  g_return_val_if_fail (element != NULL, NULL);
-
-  return GTK_ACTION_GROUP (element->data);
-}
-
 static void
 arbitrary_url_cb (GSettings  *settings,
                   const char *key,
@@ -98,33 +82,40 @@ typedef struct {
   const char *prop;
 } BindAction;
 
+static const BindAction app_actions[] = {
+  { EPHY_PREFS_LOCKDOWN_FULLSCREEN, "new-window", "enabled" },
+  { EPHY_PREFS_LOCKDOWN_FULLSCREEN, "new-incognito", "enabled" },
+
+  { EPHY_PREFS_LOCKDOWN_HISTORY, "history", "enabled" }
+};
+
 static const BindAction window_actions[] = {
-  { EPHY_PREFS_LOCKDOWN_PRINTING, "FilePrint", "sensitive" },
+  { EPHY_PREFS_LOCKDOWN_ARBITRARY_URL, "location", "enabled"},
 
-  { EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING, "FileBookmarkPage", "sensitive" },
+  { EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING, "bookmark-page", "enabled" },
 
-  { EPHY_PREFS_LOCKDOWN_ARBITRARY_URL, "GoLocation", "sensitive" },
-  { EPHY_PREFS_LOCKDOWN_SAVE_TO_DISK, "FileSaveAs", "sensitive" },
+  { EPHY_PREFS_LOCKDOWN_FULLSCREEN, "fullscreen", "enabled" },
 
-  { EPHY_PREFS_LOCKDOWN_FULLSCREEN, "ViewFullscreen", "sensitive" },
-  { EPHY_PREFS_LOCKDOWN_FULLSCREEN, "TabsDetach", "sensitive" },
-  { EPHY_PREFS_LOCKDOWN_FULLSCREEN, "FileNewWindow", "sensitive" },
-  { EPHY_PREFS_LOCKDOWN_FULLSCREEN, "FileNewWindowIncognito", "sensitive" }
+  { EPHY_PREFS_LOCKDOWN_PRINTING, "print", "enabled" },
+
+  { EPHY_PREFS_LOCKDOWN_SAVE_TO_DISK, "save-as", "enabled" }
 };
 
 static const BindAction popup_actions[] = {
-  { EPHY_PREFS_LOCKDOWN_SAVE_TO_DISK, "DownloadLinkAs", "sensitive" },
-  { EPHY_PREFS_LOCKDOWN_SAVE_TO_DISK, "SaveImageAs", "sensitive" },
-  { EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING, "ContextBookmarkPage", "sensitive" },
+  { EPHY_PREFS_LOCKDOWN_SAVE_TO_DISK, "download-link-as", "enabled" },
+  { EPHY_PREFS_LOCKDOWN_SAVE_TO_DISK, "save-image-as", "enabled" },
+  { EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING, "context-bookmark-page", "enabled" },
 
-  { EPHY_PREFS_LOCKDOWN_FULLSCREEN, "OpenLinkInNewWindow", "sensitive" }
+  { EPHY_PREFS_LOCKDOWN_FULLSCREEN, "open-link-in-new-window", "enabled" }
 };
 
-static const BindAction special_toolbar_actions[] = {
-  { EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationBack", "visible" },
-  { EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationBack", "sensitive" },
-  { EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationForward", "visible" },
-  { EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationForward", "sensitive" },
+static const BindAction tab_actions[] = {
+  { EPHY_PREFS_LOCKDOWN_FULLSCREEN, "detach", "enabled" }
+};
+
+static const BindAction toolbar_actions[] = {
+  { EPHY_PREFS_LOCKDOWN_HISTORY, "navigation-back", "enabled" },
+  { EPHY_PREFS_LOCKDOWN_HISTORY, "navigation-forward", "enabled" }
 };
 
 static gboolean
@@ -132,18 +123,18 @@ sensitive_get_mapping (GValue   *value,
                        GVariant *variant,
                        gpointer  data)
 {
-  GtkAction *action;
+  GAction *action;
   gboolean active, before, after;
 
-  action = GTK_ACTION (data);
+  action = G_ACTION (data);
   active = g_variant_get_boolean (variant);
 
-  before = gtk_action_get_sensitive (action);
-  ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, active);
-  after = gtk_action_get_sensitive (action);
+  before = g_action_get_enabled (action);
+  ephy_action_change_sensitivity_flags (G_SIMPLE_ACTION (action), LOCKDOWN_FLAG, active);
+  after = g_action_get_enabled (action);
 
-  /* Set (GtkAction::sensitive) to the value in GSettings _only if_
-   * the LOCKDOWN_FLAG had some real effect in the GtkAction */
+  /* Set (GAction::enabled) to the value in GSettings _only if_
+   * the LOCKDOWN_FLAG had some real effect in the GAction */
   g_value_set_boolean (value, (before != after) ? after : before);
 
   return TRUE;
@@ -151,35 +142,29 @@ sensitive_get_mapping (GValue   *value,
 
 static void
 bind_settings_and_actions (GSettings        *settings,
-                           GtkActionGroup   *action_group,
+                           GActionGroup     *action_group,
                            const BindAction *actions,
                            int               actions_n)
 {
   int i;
 
   for (i = 0; i < actions_n; i++) {
-    GtkAction *action;
+    GAction *action;
 
-    action = gtk_action_group_get_action (action_group,
-                                          actions[i].action);
+    action = g_action_map_lookup_action (G_ACTION_MAP (action_group),
+                                         actions[i].action);
+    g_assert (action);
 
-    if (g_strcmp0 (actions[i].prop, "visible") == 0) {
-      g_settings_bind (settings, actions[i].key,
-                       action, actions[i].prop,
-                       G_SETTINGS_BIND_GET |
-                       G_SETTINGS_BIND_INVERT_BOOLEAN);
-    } else {
-      /* We need a custom get_mapping for 'sensitive'
-       * properties, see usage of
-       * ephy_action_change_sensitivity_flags in
-       * ephy-window.c. */
-      g_settings_bind_with_mapping (settings, actions[i].key,
-                                    action, actions[i].prop,
-                                    G_SETTINGS_BIND_GET,
-                                    sensitive_get_mapping,
-                                    NULL,
-                                    action, NULL);
-    }
+    /* We need a custom get_mapping for 'enabled'
+     * properties, see usage of
+     * ephy_action_change_sensitivity_flags in
+     * ephy-window.c. */
+    g_settings_bind_with_mapping (settings, actions[i].key,
+                                  action, actions[i].prop,
+                                  G_SETTINGS_BIND_GET,
+                                  sensitive_get_mapping,
+                                  NULL,
+                                  action, NULL);
   }
 }
 
@@ -198,9 +183,9 @@ window_added_cb (GtkApplication *application,
                  GtkWindow      *window,
                  EphyLockdown   *lockdown)
 {
-  GtkUIManager *manager;
-  GtkActionGroup *action_group;
-  GtkAction *action;
+  GActionGroup *action_group;
+  EphyEmbedShellMode mode;
+  GAction *action;
   GSettings *settings;
   EphyLocationController *location_controller;
 
@@ -220,29 +205,49 @@ window_added_cb (GtkApplication *application,
   arbitrary_url_cb (EPHY_SETTINGS_LOCKDOWN,
                     EPHY_PREFS_LOCKDOWN_ARBITRARY_URL, EPHY_WINDOW (window));
 
-  manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (EPHY_WINDOW (window)));
+  mode = ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (application));
+  if (mode != EPHY_EMBED_SHELL_MODE_APPLICATION) {
+    /* These actions do not exist in application mode. */
+    action_group = G_ACTION_GROUP (G_APPLICATION (application));
+    bind_settings_and_actions (EPHY_SETTINGS_LOCKDOWN,
+                               action_group, app_actions,
+                               G_N_ELEMENTS (app_actions));
+  }
 
-  action_group = find_action_group (manager, "WindowActions");
+  action_group = gtk_widget_get_action_group (GTK_WIDGET (window),
+                                              "win");
   bind_settings_and_actions (EPHY_SETTINGS_LOCKDOWN,
-                             action_group, window_actions,
+                             action_group,
+                             window_actions,
                              G_N_ELEMENTS (window_actions));
 
-  action_group = find_action_group (manager, "PopupsActions");
+  action_group = gtk_widget_get_action_group (GTK_WIDGET (window),
+                                              "tab");
+  bind_settings_and_actions (EPHY_SETTINGS_LOCKDOWN,
+                             action_group,
+                             tab_actions,
+                             G_N_ELEMENTS (tab_actions));
+
+  action_group = gtk_widget_get_action_group (GTK_WIDGET (window),
+                                              "toolbar");
+  bind_settings_and_actions (EPHY_SETTINGS_LOCKDOWN,
+                             action_group,
+                             toolbar_actions,
+                             G_N_ELEMENTS (toolbar_actions));
+
+  action_group = gtk_widget_get_action_group (GTK_WIDGET (window),
+                                              "popup");
   bind_settings_and_actions (EPHY_SETTINGS_LOCKDOWN,
                              action_group, popup_actions,
                              G_N_ELEMENTS (popup_actions));
 
-  action = gtk_action_group_get_action (action_group,
-                                        "SetImageAsBackground");
+  action = g_action_map_lookup_action (G_ACTION_MAP (action_group),
+                                       "set-image-as-background");
   settings = ephy_settings_get ("org.gnome.desktop.background");
   g_settings_bind_writable (settings, "picture-filename",
-                            action, "sensitive", FALSE);
+                            action, "enabled", FALSE);
 
-  action_group = find_action_group (manager, "SpecialToolbarActions");
-  bind_settings_and_actions (EPHY_SETTINGS_LOCKDOWN,
-                             action_group, special_toolbar_actions,
-                             G_N_ELEMENTS (special_toolbar_actions));
-  if (ephy_embed_shell_get_mode (ephy_embed_shell_get_default ()) != EPHY_EMBED_SHELL_MODE_APPLICATION) {
+  if (mode != EPHY_EMBED_SHELL_MODE_APPLICATION) {
     location_controller = ephy_window_get_location_controller (EPHY_WINDOW (window));
     bind_location_controller (EPHY_SETTINGS_LOCKDOWN, location_controller);
   }
