@@ -4,33 +4,32 @@
  *  Copyright © 2003, 2004, 2006 Christian Persch
  *  Copyright © 2011 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
-#error "Only <epiphany/epiphany.h> can be included directly."
-#endif
+#pragma once
 
-#ifndef EPHY_SHELL_H
-#define EPHY_SHELL_H
-
-#include "ephy-bookmarks.h"
+#include "ephy-bookmarks-manager.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed.h"
+#include "ephy-history-manager.h"
+#include "ephy-open-tabs-manager.h"
+#include "ephy-password-manager.h"
 #include "ephy-session.h"
+#include "ephy-sync-service.h"
 #include "ephy-window.h"
 
 #include <webkit2/webkit2.h>
@@ -39,16 +38,9 @@
 
 G_BEGIN_DECLS
 
-#define EPHY_TYPE_SHELL         (ephy_shell_get_type ())
-#define EPHY_SHELL(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_SHELL, EphyShell))
-#define EPHY_SHELL_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_SHELL, EphyShellClass))
-#define EPHY_IS_SHELL(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_SHELL))
-#define EPHY_IS_SHELL_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_SHELL))
-#define EPHY_SHELL_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_SHELL, EphyShellClass))
+#define EPHY_TYPE_SHELL (ephy_shell_get_type ())
 
-typedef struct _EphyShell   EphyShell;
-typedef struct _EphyShellClass    EphyShellClass;
-typedef struct _EphyShellPrivate  EphyShellPrivate;
+G_DECLARE_FINAL_TYPE (EphyShell, ephy_shell, EPHY, SHELL, EphyEmbedShell)
 
 /**
  * EphyNewTabFlags:
@@ -92,21 +84,6 @@ typedef struct {
   guint32 user_time;
 } EphyShellStartupContext;
 
-struct _EphyShell {
-  EphyEmbedShell parent;
-
-  /*< private >*/
-  EphyShellPrivate *priv;
-};
-
-struct _EphyShellClass {
-  EphyEmbedShellClass parent_class;
-};
-
-GType           ephy_new_tab_flags_get_type             (void) G_GNUC_CONST;
-
-GType           ephy_shell_get_type                     (void);
-
 EphyShell      *ephy_shell_get_default                  (void);
 
 EphyEmbed      *ephy_shell_new_tab                      (EphyShell *shell,
@@ -126,24 +103,41 @@ EphySession     *ephy_shell_get_session                  (EphyShell *shell);
 
 GNetworkMonitor *ephy_shell_get_net_monitor              (EphyShell *shell);
 
-EphyBookmarks   *ephy_shell_get_bookmarks                (EphyShell *shell);
+EphyBookmarksManager *ephy_shell_get_bookmarks_manager   (EphyShell *shell);
 
-GtkWidget       *ephy_shell_get_bookmarks_editor         (EphyShell *shell);
+EphyPasswordManager *ephy_shell_get_password_manager     (EphyShell *shell);
 
-GtkWidget       *ephy_shell_get_history_window           (EphyShell *shell);
+EphyHistoryManager *ephy_shell_get_history_manager       (EphyShell *shell);
+
+EphyOpenTabsManager *ephy_shell_get_open_tabs_manager    (EphyShell *shell);
+
+EphySyncService *ephy_shell_get_sync_service             (EphyShell *shell);
+
+GtkWidget       *ephy_shell_get_history_dialog           (EphyShell *shell);
 
 GObject         *ephy_shell_get_prefs_dialog             (EphyShell *shell);
 
 guint           ephy_shell_get_n_windows                (EphyShell *shell);
 
-EphyWindow     *ephy_shell_get_main_window              (EphyShell *shell);
-
 gboolean        ephy_shell_close_all_windows            (EphyShell *shell);
 
+void            ephy_shell_try_quit                     (EphyShell *shell);
+
 void            ephy_shell_open_uris                    (EphyShell *shell,
                                                          const char **uris,
                                                          EphyStartupFlags startup_flags,
                                                          guint32 user_time);
-G_END_DECLS
 
-#endif
+void            ephy_shell_set_startup_context          (EphyShell               *shell,
+                                                         EphyShellStartupContext *ctx);
+
+EphyShellStartupContext *ephy_shell_startup_context_new (EphyStartupFlags  startup_flags,
+                                                         char             *bookmarks_filename,
+                                                         char             *session_filename,
+                                                         char             *bookmark_url,
+                                                         char            **arguments,
+                                                         guint32           user_time);
+
+void            _ephy_shell_create_instance             (EphyEmbedShellMode mode);
+
+G_END_DECLS
