@@ -18,17 +18,6 @@
  *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* Portions of this file based on Chromium code.
- * License block as follows:
- *
- * Copyright (c) 2009 The Chromium Authors. All rights reserved.
- * Use of this source code is governed by a BSD-style license that can be
- * found in the LICENSE file.
- *
- * The LICENSE file from Chromium can be found in the LICENSE.chromium
- * file.
- */
-
 #include "config.h"
 
 #include "ephy-bookmarks-manager.h"
@@ -41,19 +30,25 @@
 #include "ephy-search-engine-manager.h"
 #include "ephy-settings.h"
 #include "ephy-sqlite-connection.h"
+#include "ephy-string.h"
+#include "ephy-sync-debug.h"
 #include "ephy-sync-utils.h"
 #include "ephy-uri-tester-shared.h"
 #include "ephy-web-app-utils.h"
+#include "gvdb-builder.h"
+#include "gvdb-reader.h"
 
 #include <errno.h>
 #include <fcntl.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
+#include <inttypes.h>
 #include <libsecret/secret.h>
 #include <libsoup/soup.h>
 #include <libxml/HTMLtree.h>
 #include <libxml/xmlreader.h>
 #include <locale.h>
+#include <math.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <webkit2/webkit2.h>
@@ -61,7 +56,6 @@
 static int do_step_n = -1;
 static int migration_version = -1;
 static char *profile_dir = NULL;
-static GMainLoop *loop = NULL;
 
 /*
  * What to do to add new migration steps:
@@ -77,328 +71,6 @@ profile_dir_exists (void)
   return g_file_test (ephy_dot_dir (), G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR);
 }
 
-static void
-migrate_profile (const char *old_dir,
-                 const char *new_dir)
-{
-  char *parent_dir;
-  char *updated;
-  const char *message;
-
-  if (g_file_test (new_dir, G_FILE_TEST_EXISTS) ||
-      !g_file_test (old_dir, G_FILE_TEST_IS_DIR))
-    return;
-
-  /* Test if we already attempted to migrate first. */
-  updated = g_build_filename (old_dir, "DEPRECATED-DIRECTORY", NULL);
-  message = _("Web 3.6 deprecated this directory and tried migrating "
-              "this configuration to ~/.config/epiphany");
-
-  parent_dir = g_path_get_dirname (new_dir);
-  if (g_mkdir_with_parents (parent_dir, 0700) == 0) {
-    int fd, res;
-
-    /* rename() works fine if the destination directory is empty. */
-    res = g_rename (old_dir, new_dir);
-    if (res == -1 && !g_file_test (updated, G_FILE_TEST_EXISTS)) {
-      fd = g_creat (updated, 0600);
-      if (fd != -1) {
-        res = write (fd, message, strlen (message));
-        close (fd);
-      }
-    }
-  }
-
-  g_free (parent_dir);
-  g_free (updated);
-}
-
-static void
-migrate_profile_gnome2_to_xdg (void)
-{
-  char *old_dir;
-  char *new_dir;
-
-  old_dir = g_build_filename (g_get_home_dir (),
-                              ".gnome2",
-                              "epiphany",
-                              NULL);
-  new_dir = g_build_filename (g_get_user_config_dir (),
-                              "epiphany",
-                              NULL);
-
-  migrate_profile (old_dir, new_dir);
-
-  g_free (new_dir);
-  g_free (old_dir);
-}
-
-static char *
-fix_desktop_file_and_return_new_location (const char *dir)
-{
-  GRegex *regex;
-  char *result, *old_profile_dir, *replacement, *contents, *new_contents;
-  gsize length;
-
-  old_profile_dir = g_build_filename (g_get_home_dir (),
-                                      ".gnome2",
-                                      NULL);
-  replacement = g_build_filename (g_get_user_config_dir (),
-                                  NULL);
-  regex = g_regex_new (old_profile_dir, 0, 0, NULL);
-
-  /* We want to modify both the link destination and the contents of
-   * the .desktop file itself. */
-  result = g_regex_replace (regex, dir, -1,
-                            0, replacement, 0, NULL);
-  g_file_get_contents (result, &contents, &length, NULL);
-  new_contents = g_regex_replace (regex, contents, -1, 0,
-                                  replacement, 0, NULL);
-  g_file_set_contents (result, new_contents, length, NULL);
-
-  g_free (contents);
-  g_free (new_contents);
-  g_free (old_profile_dir);
-  g_free (replacement);
-
-  g_regex_unref (regex);
-
-  return result;
-}
-
-static void
-migrate_web_app_links (void)
-{
-  GList *apps, *p;
-
-  apps = ephy_web_application_get_application_list ();
-  for (p = apps; p; p = p->next) {
-    char *desktop_file, *app_link;
-    EphyWebApplication *app = (EphyWebApplication *)p->data;
-
-    desktop_file = app->desktop_file;
-
-    /* Update the link in applications. */
-    app_link = g_build_filename (g_get_user_data_dir (), "applications", desktop_file, NULL);
-    if (g_file_test (app_link, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_SYMLINK)) {
-      /* Change the link to point to the new profile dir. */
-      GFileInfo *info;
-      const char *target;
-      GFile *file = g_file_new_for_path (app_link);
-
-      info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET,
-                                0, NULL, NULL);
-      if (info) {
-        char *new_target;
-
-        target = g_file_info_get_symlink_target (info);
-        new_target = fix_desktop_file_and_return_new_location (target);
-
-        /* FIXME: Updating the file info and setting it again should
-         * work, but it does not? Just delete and create the link
-         * again. */
-        g_file_delete (file, 0, 0);
-        g_object_unref (file);
-
-        file = g_file_new_for_path (app_link);
-        g_file_make_symbolic_link (file, new_target, NULL, NULL);
-
-        g_object_unref (info);
-        g_free (new_target);
-      }
-
-      g_object_unref (file);
-    }
-
-    g_free (app_link);
-  }
-
-  ephy_web_application_free_application_list (apps);
-}
-
-static void
-migrate_new_urls_table (void)
-{
-  EphySQLiteConnection *history_database;
-  char *filename;
-  GError *error = NULL;
-
-  filename = g_build_filename (ephy_dot_dir (), EPHY_HISTORY_FILE, NULL);
-  if (!g_file_test (filename, G_FILE_TEST_EXISTS))
-    return;
-
-  history_database = ephy_sqlite_connection_new (EPHY_SQLITE_CONNECTION_MODE_READWRITE);
-  ephy_sqlite_connection_open (history_database, filename, &error);
-
-  if (error) {
-    g_warning ("Failed to open history database: %s", error->message);
-    g_error_free (error);
-    g_free (filename);
-    return;
-  }
-
-  ephy_sqlite_connection_execute (history_database,
-                                  "ALTER TABLE urls "
-                                  "ADD COLUMN thumbnail_update_time INTEGER DEFAULT 0",
-                                  &error);
-  if (error) {
-    g_warning ("Failed to add new column to table in history backend: %s",
-               error->message);
-    g_error_free (error);
-    error = NULL;
-  }
-  ephy_sqlite_connection_execute (history_database,
-                                  "ALTER TABLE urls "
-                                  "ADD COLUMN hidden_from_overview INTEGER DEFAULT 0",
-                                  &error);
-  if (error) {
-    g_warning ("Failed to add new column to table in history backend: %s",
-               error->message);
-    g_error_free (error);
-    error = NULL;
-  }
-
-  g_object_unref (history_database);
-  g_free (filename);
-}
-
-/* Migrating form password data. */
-
-static int form_passwords_migrating = 0;
-
-
-static void
-password_cleared_cb (SecretService *service,
-                     GAsyncResult  *res,
-                     gpointer       userdata)
-{
-  secret_service_clear_finish (service, res, NULL);
-
-  if (g_atomic_int_dec_and_test (&form_passwords_migrating))
-    g_main_loop_quit (loop);
-}
-
-static void
-store_form_auth_data_cb (GObject      *object,
-                         GAsyncResult *res,
-                         GHashTable   *attributes)
-{
-  GError *error = NULL;
-
-  if (ephy_password_manager_store_finish (res, &error) == FALSE) {
-    g_warning ("Couldn't store a form password: %s", error->message);
-    g_error_free (error);
-    goto out;
-  }
-
-  g_atomic_int_inc (&form_passwords_migrating);
-  secret_service_clear (NULL, NULL,
-                        attributes, NULL, (GAsyncReadyCallback)password_cleared_cb,
-                        NULL);
-
- out:
-  if (g_atomic_int_dec_and_test (&form_passwords_migrating))
-    g_main_loop_quit (loop);
-
-  g_hash_table_unref (attributes);
-}
-
-static void
-load_collection_items_cb (SecretCollection *collection,
-                          GAsyncResult     *res,
-                          gpointer          data)
-{
-  SecretItem *item;
-  SecretValue *secret;
-  GList *l;
-  GHashTable *attributes, *t;
-  const char *server, *username, *username_field, *password_field, *password;
-  char *origin;
-  SoupURI *uri;
-  GError *error = NULL;
-  GList *items;
-
-  secret_collection_load_items_finish (collection, res, &error);
-
-  if (error) {
-    g_warning ("Couldn't retrieve form data: %s", error->message);
-    g_error_free (error);
-    return;
-  }
-  items = secret_collection_get_items (collection);
-
-  for (l = items; l; l = l->next) {
-    item = (SecretItem *)l->data;
-
-    attributes = secret_item_get_attributes (item);
-    server = g_hash_table_lookup (attributes, "server");
-    if (server &&
-        g_strstr_len (server, -1, "form%5Fusername") &&
-        g_strstr_len (server, -1, "form%5Fpassword")) {
-      g_atomic_int_inc (&form_passwords_migrating);
-      /* This is one of the hackish ones that need to be migrated.
-         Fetch the rest of the data and take care of it. */
-      username = g_hash_table_lookup (attributes, "user");
-      uri = soup_uri_new (server);
-      t = soup_form_decode (uri->query);
-      username_field = g_hash_table_lookup (t, USERNAME_FIELD_KEY);
-      password_field = g_hash_table_lookup (t, PASSWORD_FIELD_KEY);
-      soup_uri_set_query (uri, NULL);
-      origin = soup_uri_to_string (uri, FALSE);
-      secret_item_load_secret_sync (item, NULL, NULL);
-      secret = secret_item_get_secret (item);
-      password = secret_value_get (secret, NULL);
-      ephy_password_manager_store_raw (origin,
-                                       username,
-                                       password,
-                                       username_field,
-                                       password_field,
-                                       (GAsyncReadyCallback)store_form_auth_data_cb,
-                                       g_hash_table_ref (attributes));
-      g_free (origin);
-      secret_value_unref (secret);
-      g_hash_table_unref (t);
-      soup_uri_free (uri);
-    }
-    g_hash_table_unref (attributes);
-  }
-
-  /* And decrease here so that we finish eventually. */
-  if (g_atomic_int_dec_and_test (&form_passwords_migrating))
-    g_main_loop_quit (loop);
-
-  g_list_free_full (items, (GDestroyNotify)g_object_unref);
-}
-
-static void
-migrate_form_passwords_to_libsecret (void)
-{
-  SecretService *service;
-  GList *collections, *c;
-  GError *error = NULL;
-
-  service = secret_service_get_sync (SECRET_SERVICE_OPEN_SESSION | SECRET_SERVICE_LOAD_COLLECTIONS, NULL, &error);
-  if (error) {
-    g_warning ("Could not get the secret service: %s", error->message);
-    g_error_free (error);
-    return;
-  }
-
-  collections = secret_service_get_collections (service);
-
-  for (c = collections; c; c = c->next) {
-    g_atomic_int_inc (&form_passwords_migrating);
-    secret_collection_load_items ((SecretCollection *)c->data, NULL, (GAsyncReadyCallback)load_collection_items_cb,
-                                  NULL);
-  }
-
-  loop = g_main_loop_new (NULL, FALSE);
-  g_main_loop_run (loop);
-
-  g_list_free_full (collections, (GDestroyNotify)g_object_unref);
-  g_object_unref (service);
-}
-
 static void
 migrate_app_desktop_file_categories (void)
 {
@@ -781,7 +453,7 @@ migrate_adblock_filters (void)
         char *url;
 
         url = g_strstrip (filter_list[i]);
-        if (url[0] != '\0' && !g_str_equal (url, ADBLOCK_DEFAULT_FILTER_URL))
+        if (url[0] != '\0' && strcmp (url, ADBLOCK_DEFAULT_FILTER_URL))
           g_ptr_array_add (filters_array, g_strdup (url));
       }
 
@@ -868,7 +540,7 @@ static gboolean
 is_deprecated_setting (const char *setting)
 {
   for (guint i = 0; i < G_N_ELEMENTS (deprecated_settings); i++) {
-    if (g_str_equal (setting, deprecated_settings[i]))
+    if (!strcmp (setting, deprecated_settings[i]))
       return TRUE;
   }
 
@@ -923,6 +595,9 @@ migrate_settings (void)
   g_settings_sync ();
 }
 
+/* Originally migrator #17, but moved to spot #27 because it uses the
+ * bookmarks manager, which requires that we have already run #24.
+ */
 static void
 migrate_search_engines (void)
 {
@@ -936,6 +611,11 @@ migrate_search_engines (void)
   char *default_search_engine_address;
   const char *default_search_engine_name = _("Search the Web");
 
+  /* Search engine settings are only used in browser mode, so no need to migrate
+   * if we are not in browser mode. */
+  if (!ephy_dot_dir_is_default ())
+    return;
+
   bookmarks_manager = ephy_bookmarks_manager_new ();
   search_engine_manager = ephy_search_engine_manager_new ();
 
@@ -1085,10 +765,12 @@ migrate_history_to_firefox_sync_history (void)
     goto out;
   }
 
-  history_db = ephy_sqlite_connection_new (EPHY_SQLITE_CONNECTION_MODE_READWRITE);
-  ephy_sqlite_connection_open (history_db, history_filename, &error);
+  history_db = ephy_sqlite_connection_new (EPHY_SQLITE_CONNECTION_MODE_READWRITE,
+                                           history_filename);
+  ephy_sqlite_connection_open (history_db, &error);
   if (error) {
     g_warning ("Failed to open history database: %s", error->message);
+    g_clear_object (&history_db);
     goto out;
   }
 
@@ -1116,8 +798,10 @@ migrate_history_to_firefox_sync_history (void)
 
 out:
   g_free (history_filename);
-  if (history_db)
+  if (history_db) {
+    ephy_sqlite_connection_close (history_db);
     g_object_unref (history_db);
+  }
   if (statement)
     g_object_unref (statement);
   if (error)
@@ -1197,6 +881,340 @@ out:
   g_list_free_full (passwords, g_object_unref);
 }
 
+static const char * const old_sync_settings[] = {
+    EPHY_PREFS_SYNC_USER,
+    EPHY_PREFS_SYNC_TIME,
+    EPHY_PREFS_SYNC_DEVICE_ID,
+    EPHY_PREFS_SYNC_DEVICE_NAME,
+    EPHY_PREFS_SYNC_FREQUENCY,
+    EPHY_PREFS_SYNC_WITH_FIREFOX,
+    EPHY_PREFS_SYNC_BOOKMARKS_ENABLED,
+    EPHY_PREFS_SYNC_BOOKMARKS_TIME,
+    EPHY_PREFS_SYNC_BOOKMARKS_INITIAL,
+    EPHY_PREFS_SYNC_PASSWORDS_ENABLED,
+    EPHY_PREFS_SYNC_PASSWORDS_TIME,
+    EPHY_PREFS_SYNC_PASSWORDS_INITIAL,
+    EPHY_PREFS_SYNC_HISTORY_ENABLED,
+    EPHY_PREFS_SYNC_HISTORY_TIME,
+    EPHY_PREFS_SYNC_HISTORY_INITIAL,
+    EPHY_PREFS_SYNC_OPEN_TABS_ENABLED,
+    EPHY_PREFS_SYNC_OPEN_TABS_TIME
+};
+
+static void
+migrate_sync_settings_path (void)
+{
+  GSettings *deprecated_settings = ephy_settings_get ("org.gnome.Epiphany.sync.DEPRECATED");
+
+  /* Sync settings are only used in browser mode, so no need to migrate if we
+   * are not in browser mode. */
+  if (!ephy_dot_dir_is_default ())
+    return;
+
+  for (guint i = 0; i < G_N_ELEMENTS (old_sync_settings); i++) {
+    GVariant *user_value;
+
+    /* Has the setting been changed from its default? */
+    user_value = g_settings_get_user_value (deprecated_settings, old_sync_settings[i]);
+
+    if (user_value != NULL) {
+      GVariant *value;
+      const GVariantType *type;
+
+      value = g_settings_get_value (deprecated_settings, old_sync_settings[i]);
+      type = g_variant_get_type (value);
+
+      /* All double values in the old sync schema have been converted to gint64 in the new schema. */
+      if (g_variant_type_equal (type, G_VARIANT_TYPE_DOUBLE)) {
+        g_settings_set_value (EPHY_SETTINGS_SYNC, old_sync_settings[i],
+                              g_variant_new_int64 (ceil (g_variant_get_double (value))));
+      } else {
+        g_settings_set_value (EPHY_SETTINGS_SYNC, old_sync_settings[i], value);
+      }
+
+      /* We do not want to ever run this migration again, to avoid writing old
+       * values over new ones. So be cautious and reset the old settings. */
+      g_settings_reset (deprecated_settings, old_sync_settings[i]);
+
+      g_variant_unref (value);
+      g_variant_unref (user_value);
+    }
+  }
+
+  g_settings_sync ();
+}
+
+static void
+migrate_sync_device_info (void)
+{
+  JsonObject *device;
+  const char *device_id;
+  const char *device_name;
+  char *prev_device_id;
+  char *device_bso_id;
+  char *record;
+  int default_profile_migration_version;
+
+  default_profile_migration_version = ephy_profile_utils_get_migration_version_for_profile_dir (ephy_default_dot_dir ());
+  if (default_profile_migration_version >= EPHY_SYNC_DEVICE_ID_MIGRATION_VERSION)
+    return;
+
+  if (!ephy_sync_utils_user_is_signed_in ())
+    return;
+
+  /* Fetch the device info from the Firefox Accounts Server. */
+  device = ephy_sync_debug_get_current_device ();
+  if (!device) {
+    g_warning ("Failed to migrate sync device info. Sign in again to Sync "
+               "to have your device re-registered and continue syncing.");
+    return;
+  }
+
+  /* Erase previous records from the Sync Storage Server. */
+  prev_device_id = ephy_sync_utils_get_device_id ();
+  ephy_sync_debug_erase_record ("clients", prev_device_id);
+  ephy_sync_debug_erase_record ("tabs", prev_device_id);
+
+  /* Use the device id and name assigned by the Firefox Accounts Server at sign in.
+   * The user can change later the device name in the Preferences dialog. */
+  device_id = json_object_get_string_member (device, "id");
+  ephy_sync_utils_set_device_id (device_id);
+  device_name = json_object_get_string_member (device, "name");
+  ephy_sync_utils_set_device_name (device_name);
+
+  device_bso_id = ephy_sync_utils_get_device_bso_id ();
+  record = ephy_sync_utils_make_client_record (device_bso_id, device_id, device_name);
+  ephy_sync_debug_upload_record ("clients", device_bso_id, record);
+
+  g_free (record);
+  g_free (device_bso_id);
+  g_free (prev_device_id);
+  json_object_unref (device);
+}
+
+static GVariant *
+convert_bookmark_timestamp (GVariant *value)
+{
+  GVariantBuilder builder;
+  GVariantIter *iter;
+  gboolean is_uploaded;
+  gint64 time_added;
+  gint64 timestamp_i;
+  double timestamp_d;
+  const char *title;
+  const char *id;
+  char *tag;
+
+  if (!g_variant_check_format_string (value, "(xssdbas)", FALSE))
+    return NULL;
+
+  g_variant_get (value, "(x&s&sdbas)",
+                 &time_added, &title, &id,
+                 &timestamp_d, &is_uploaded, &iter);
+  timestamp_i = ceil (timestamp_d);
+
+  g_variant_builder_init (&builder, G_VARIANT_TYPE ("(xssxbas)"));
+  g_variant_builder_add (&builder, "x", time_added);
+  g_variant_builder_add (&builder, "s", title);
+  g_variant_builder_add (&builder, "s", id);
+  g_variant_builder_add (&builder, "x", timestamp_i);
+  g_variant_builder_add (&builder, "b", is_uploaded);
+
+  g_variant_builder_open (&builder, G_VARIANT_TYPE ("as"));
+  while (g_variant_iter_next (iter, "s", &tag)) {
+    g_variant_builder_add (&builder, "s", tag);
+    g_free (tag);
+  }
+  g_variant_builder_close (&builder);
+
+  g_variant_iter_free (iter);
+
+  return g_variant_builder_end (&builder);
+}
+
+static void
+migrate_bookmarks_timestamp (void)
+{
+  GvdbTable *root_table_in = NULL;
+  GvdbTable *bookmarks_table_in = NULL;
+  GvdbTable *tags_table_in = NULL;
+  GHashTable *root_table_out = NULL;
+  GHashTable *bookmarks_table_out = NULL;
+  GHashTable *tags_table_out = NULL;
+  GError *error = NULL;
+  char **tags = NULL;
+  char **urls = NULL;
+  char *filename;
+  int length;
+
+  filename = g_build_filename (ephy_dot_dir (), EPHY_BOOKMARKS_FILE, NULL);
+  root_table_in = gvdb_table_new (filename, TRUE, &error);
+  if (error) {
+    g_warning ("Failed to create Gvdb table: %s", error->message);
+    goto out;
+  }
+
+  bookmarks_table_in = gvdb_table_get_table (root_table_in, "bookmarks");
+  if (!bookmarks_table_in) {
+    g_warning ("Failed to find bookmarks inner table");
+    goto out;
+  }
+
+  tags_table_in = gvdb_table_get_table (root_table_in, "tags");
+  if (!tags_table_in) {
+    g_warning ("Failed to find tags inner table");
+    goto out;
+  }
+
+  root_table_out = gvdb_hash_table_new (NULL, NULL);
+  bookmarks_table_out = gvdb_hash_table_new (root_table_out, "bookmarks");
+  tags_table_out = gvdb_hash_table_new (root_table_out, "tags");
+
+  tags = gvdb_table_get_names (tags_table_in, &length);
+  for (int i = 0; i < length; i++)
+    gvdb_hash_table_insert (tags_table_out, tags[i]);
+
+  urls = gvdb_table_get_names (bookmarks_table_in, &length);
+  for (int i = 0; i < length; i++) {
+    GVariant *value = gvdb_table_get_value (bookmarks_table_in, urls[i]);
+    GVariant *new_value = convert_bookmark_timestamp (value);
+    if (new_value != NULL) {
+      GvdbItem *item = gvdb_hash_table_insert (bookmarks_table_out, urls[i]);
+      gvdb_item_set_value (item, new_value);
+    }
+    g_variant_unref (value);
+
+    if (new_value == NULL)
+      goto out;
+  }
+
+  gvdb_table_write_contents (root_table_out, filename, FALSE, NULL);
+
+out:
+  if (error)
+    g_error_free (error);
+  if (root_table_out)
+    g_hash_table_unref (root_table_out);
+  if (bookmarks_table_out)
+    g_hash_table_unref (bookmarks_table_out);
+  if (tags_table_out)
+    g_hash_table_unref (tags_table_out);
+  if (root_table_in)
+    gvdb_table_free (root_table_in);
+  if (bookmarks_table_in)
+    gvdb_table_free (bookmarks_table_in);
+  if (tags_table_in)
+    gvdb_table_free (tags_table_in);
+  g_strfreev (urls);
+  g_strfreev (tags);
+  g_free (filename);
+}
+
+static void
+migrate_passwords_timestamp (void)
+{
+  GHashTable *attributes;
+  GHashTable *attrs;
+  SecretItem *item;
+  SecretValue *value;
+  GList *passwords = NULL;
+  GError *error = NULL;
+  const char *origin;
+  const char *username;
+  const char *timestamp;
+  char *label;
+  double timestamp_d;
+  gint64 timestamp_i;
+  int default_profile_migration_version;
+
+  /* We want this migration to run only once. */
+  default_profile_migration_version = ephy_profile_utils_get_migration_version_for_profile_dir (ephy_default_dot_dir ());
+  if (default_profile_migration_version >= EPHY_PASSWORDS_TIMESTAMP_MIGRATION_VERSION)
+    return;
+
+  attributes = secret_attributes_build (EPHY_FORM_PASSWORD_SCHEMA, NULL);
+  passwords = secret_service_search_sync (NULL, EPHY_FORM_PASSWORD_SCHEMA, attributes,
+                                          SECRET_SEARCH_ALL | SECRET_SEARCH_UNLOCK | SECRET_SEARCH_LOAD_SECRETS,
+                                          NULL, &error);
+  if (error) {
+    g_warning ("Failed to search the password schema: %s", error->message);
+    goto out;
+  }
+
+  secret_service_clear_sync (NULL, EPHY_FORM_PASSWORD_SCHEMA,
+                             attributes, NULL, &error);
+  if (error) {
+    g_warning ("Failed to clear the password schema: %s", error->message);
+    goto out;
+  }
+
+  for (GList *p = passwords; p && p->data; p = p->next) {
+    item = (SecretItem *)p->data;
+    value = secret_item_get_secret (item);
+
+    if (!value)
+      continue;
+
+    attrs = secret_item_get_attributes (item);
+    origin = g_hash_table_lookup (attrs, ORIGIN_KEY);
+    username = g_hash_table_lookup (attrs, USERNAME_KEY);
+    timestamp = g_hash_table_lookup (attrs, SERVER_TIME_MODIFIED_KEY);
+
+    if (!origin || !timestamp)
+      goto next;
+
+    timestamp_d = g_ascii_strtod (timestamp, NULL);
+    timestamp_i = (gint64)ceil (timestamp_d);
+    g_hash_table_insert (attrs, g_strdup (SERVER_TIME_MODIFIED_KEY), g_strdup_printf ("%"PRId64, timestamp_i));
+
+    if (username)
+      label = g_strdup_printf ("Password for %s in a form in %s", username, origin);
+    else
+      label = g_strdup_printf ("Password in a form in %s", origin);
+
+    secret_service_store_sync (NULL, EPHY_FORM_PASSWORD_SCHEMA,
+                               attrs, NULL, label,
+                               value, NULL, &error);
+    if (error) {
+      g_warning ("Failed to store password: %s", error->message);
+      g_clear_pointer (&error, g_error_free);
+    }
+
+    g_free (label);
+next:
+    g_hash_table_unref (attrs);
+    secret_value_unref (value);
+  }
+
+out:
+  if (error)
+    g_error_free (error);
+  g_hash_table_unref (attributes);
+  g_list_free_full (passwords, g_object_unref);
+}
+
+static void
+migrate_annoyance_list (void)
+{
+  GVariant *user_value;
+  const char **filters;
+  char **modified_filters;
+
+  /* Has the filters setting been modified? If not, we're done. */
+  user_value = g_settings_get_user_value (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS);
+  if (!user_value)
+    return;
+
+  /* The annoyance list was causing a bunch of problems. Forcibly remove it. */
+  filters = g_variant_get_strv (user_value, NULL);
+  modified_filters = ephy_strv_remove (filters, "https://easylist.to/easylist/fanboy-annoyance.txt");
+  g_settings_set_strv (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS, (const char * const *)modified_filters);
+
+  g_variant_unref (user_value);
+  g_free (filters);
+  g_strfreev (modified_filters);
+}
+
 static void
 migrate_nothing (void)
 {
@@ -1217,9 +1235,9 @@ const EphyProfileMigrator migrators[] = {
   /*  4 */ migrate_nothing,
   /*  5 */ migrate_nothing,
   /*  6 */ migrate_nothing,
-  /*  7 */ migrate_web_app_links,
-  /*  8 */ migrate_new_urls_table,
-  /*  9 */ migrate_form_passwords_to_libsecret,
+  /*  7 */ migrate_nothing,
+  /*  8 */ migrate_nothing,
+  /*  9 */ migrate_nothing,
   /* 10 */ migrate_app_desktop_file_categories,
   /* 11 */ migrate_insecure_passwords,
   /* 12 */ migrate_bookmarks,
@@ -1227,11 +1245,18 @@ const EphyProfileMigrator migrators[] = {
   /* 14 */ migrate_initial_state,
   /* 15 */ migrate_permissions,
   /* 16 */ migrate_settings,
-  /* 17 */ migrate_search_engines,
+  /* 17 */ migrate_nothing,
   /* 18 */ migrate_icon_database,
   /* 19 */ migrate_passwords_to_firefox_sync_passwords,
   /* 20 */ migrate_history_to_firefox_sync_history,
   /* 21 */ migrate_passwords_add_target_origin,
+  /* 22 */ migrate_sync_settings_path,
+  /* 23 */ migrate_sync_device_info,
+  /* 24 */ migrate_bookmarks_timestamp,
+  /* 25 */ migrate_passwords_timestamp,
+  /* 26 */ migrate_nothing,
+  /* 27 */ migrate_search_engines,
+  /* 28 */ migrate_annoyance_list
 };
 
 static gboolean
@@ -1240,12 +1265,8 @@ ephy_migrator (void)
   int latest, i;
   EphyProfileMigrator m;
 
-  /* Always try to migrate the data from the old profile dir at the
-   * very beginning. */
-  migrate_profile_gnome2_to_xdg ();
-
   /* If after this point there's no profile dir, there's no point in
-   * running anything because Epiphany has never run in this sytem, so
+   * running anything because Epiphany has never run in this system, so
    * exit here. */
   if (!profile_dir_exists ())
     return TRUE;
