@@ -1,25 +1,21 @@
-/* vim: set sw=2 ts=2 sts=2 et: */
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
- * ephy-download-test.c
- * This file is part of Epiphany
+ *  Copyright © 2011 Igalia S.L.
  *
- * Copyright © 2011 - Igalia S.L.
+ *  This file is part of Epiphany.
  *
- * Epiphany is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * Epiphany is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  Epiphany is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Epiphany; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ *  You should have received a copy of the GNU General Public License
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -27,7 +23,6 @@
 #include "ephy-download.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-file-helpers.h"
-#include "ephy-private.h"
 #include "ephy-shell.h"
 
 #include <glib.h>
@@ -53,16 +48,16 @@ get_uri_for_path (const char *path)
 }
 
 static void
-server_callback (SoupServer *server,
-                 SoupMessage *msg,
-                 const char *path,
-                 GHashTable *query,
+server_callback (SoupServer        *server,
+                 SoupMessage       *msg,
+                 const char        *path,
+                 GHashTable        *query,
                  SoupClientContext *context,
-                 gpointer data)
+                 gpointer           data)
 {
   soup_message_set_status (msg, SOUP_STATUS_OK);
 
-  if (g_str_equal (path, "/cancelled"))
+  if (!strcmp (path, "/cancelled"))
     soup_message_set_status (msg, SOUP_STATUS_CANT_CONNECT);
 
   soup_message_body_append (msg->response_body, SOUP_MEMORY_STATIC,
@@ -88,7 +83,7 @@ fixture_setup (Fixture *fixture, gconstpointer data)
   dest_file = g_build_filename (ephy_file_tmp_dir (), tmp_filename, NULL);
 
   fixture->source = get_uri_for_path ("/default");
-  fixture->download = ephy_download_new_for_uri (fixture->source, NULL);
+  fixture->download = ephy_download_new_for_uri (fixture->source);
   fixture->destination = g_filename_to_uri (dest_file, NULL, NULL);
   fixture->loop = g_main_loop_new (NULL, TRUE);
 
@@ -126,7 +121,7 @@ test_file_was_downloaded (EphyDownload *download)
 
 static void
 completed_cb (EphyDownload *download,
-              Fixture *fixture)
+              Fixture      *fixture)
 {
   g_assert (test_file_was_downloaded (download));
   g_main_loop_quit (fixture->loop);
@@ -144,7 +139,7 @@ test_ephy_download_new_for_uri (Fixture *fixture, gconstpointer data)
   WebKitDownload *download = ephy_download_get_webkit_download (fixture->download);
   WebKitURIRequest *request = webkit_download_get_request (download);
 
-  g_assert(request);
+  g_assert (request);
   g_assert_cmpstr (fixture->source, ==, webkit_uri_request_get_uri (request));
 }
 
@@ -154,7 +149,6 @@ test_ephy_download_start (Fixture *fixture, gconstpointer data)
   g_signal_connect (G_OBJECT (fixture->download), "completed",
                     G_CALLBACK (completed_cb), fixture);
 
-  ephy_download_set_action (fixture->download, EPHY_DOWNLOAD_ACTION_DO_NOTHING);
   g_main_loop_run (fixture->loop);
 }
 
@@ -162,7 +156,7 @@ int
 main (int argc, char *argv[])
 {
   int ret;
-  GSList* uris;
+  GSList *uris;
   SoupServer *server;
 
   gtk_test_init (&argc, &argv);
@@ -184,7 +178,7 @@ main (int argc, char *argv[])
                             SOUP_SERVER_LISTEN_IPV4_ONLY,
                             NULL);
   uris = soup_server_get_uris (server);
-  base_uri = (SoupURI*)uris->data;
+  base_uri = (SoupURI *)uris->data;
   g_slist_free (uris);
 
   soup_server_add_handler (server, NULL, server_callback, NULL, NULL);
