@@ -1,21 +1,21 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
- * Copyright © 2012 - Igalia S.L.
+ *  Copyright © 2012 - Igalia S.L.
  *
- * Epiphany is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ *  This file is part of Epiphany.
  *
- * Epiphany is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * You should have received a copy of the GNU General Public License
- * along with Epiphany; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ *  Epiphany is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -24,7 +24,7 @@
 #include "ephy-embed-prefs.h"
 #include "ephy-encodings.h"
 #include "ephy-file-helpers.h"
-#include "ephy-private.h"
+#include "ephy-settings.h"
 #include "ephy-shell.h"
 
 #include <gtk/gtk.h>
@@ -56,7 +56,7 @@ test_ephy_encodings_get (void)
   EphyEncodings *encodings;
   GList *all, *p;
 
-  encodings = EPHY_ENCODINGS (ephy_embed_shell_get_encodings (embed_shell));
+  encodings = ephy_embed_shell_get_encodings (embed_shell);
   g_assert (encodings);
 
   all = ephy_encodings_get_all (encodings);
